<!--- app-name: Grafana Tempo -->

# Bitnami package for Grafana Tempo

Grafana Tempo is a distributed tracing system that has out-of-the-box integration with Grafana. It is highly scalable and works with many popular tracing protocols.

[Overview of Grafana Tempo](https://github.com/grafana/tempo)

Trademarks: This software listing is packaged by Bitnami. The respective trademarks mentioned in the offering are owned by the respective companies, and use of them does not imply any affiliation or endorsement.

## TL;DR

```console
helm install my-release oci://registry-1.docker.io/bitnamicharts/grafana-tempo
```

Looking to use Grafana Tempo in production? Try [VMware Tanzu Application Catalog](https://bitnami.com/enterprise), the commercial edition of the Bitnami catalog.

## Introduction

Bitnami charts for Helm are carefully engineered, actively maintained and are the quickest and easiest way to deploy containers on a Kubernetes cluster that are ready to handle production workloads.

This chart bootstraps a [Grafana Tempo](https://github.com/grafana/tempo) Deployment in a [Kubernetes](https://kubernetes.io) cluster using the [Helm](https://helm.sh) package manager.

Bitnami charts can be used with [Kubeapps](https://kubeapps.dev/) for deployment and management of Helm Charts in clusters.

## Prerequisites

- Kubernetes 1.23+
- Helm 3.8.0+
- PV provisioner support in the underlying infrastructure

## Installing the Chart

To install the chart with the release name `my-release`:

```console
helm install my-release oci://REGISTRY_NAME/REPOSITORY_NAME/grafana-tempo
```

> Note: You need to substitute the placeholders `REGISTRY_NAME` and `REPOSITORY_NAME` with a reference to your Helm chart registry and repository. For example, in the case of Bitnami, you need to use `REGISTRY_NAME=registry-1.docker.io` and `REPOSITORY_NAME=bitnamicharts`.

The command deploys grafana-tempo on the Kubernetes cluster in the default configuration. The [Parameters](#parameters) section lists the parameters that can be configured during installation.

> **Tip**: List all releases using `helm list`

## Configuration and installation details

### Resource requests and limits

Bitnami charts allow setting resource requests and limits for all containers inside the chart deployment. These are inside the `resources` value (check parameter table). Setting requests is essential for production workloads and these should be adapted to your specific use case.

To make this process easier, the chart contains the `resourcesPreset` values, which automatically sets the `resources` section according to different presets. Check these presets in [the bitnami/common chart](https://github.com/bitnami/charts/blob/main/bitnami/common/templates/_resources.tpl#L15). However, in production workloads using `resourcePreset` is discouraged as it may not fully adapt to your specific needs. Find more information on container resource management in the [official Kubernetes documentation](https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/).

### [Rolling VS Immutable tags](https://docs.vmware.com/en/VMware-Tanzu-Application-Catalog/services/tutorials/GUID-understand-rolling-tags-containers-index.html)

It is strongly recommended to use immutable tags in a production environment. This ensures your deployment does not change automatically if the same tag is updated with a different image.

Bitnami will release a new chart updating its containers if a new version of the main container, significant changes, or critical vulnerabilities exist.

### Tempo configuration

The tempo configuration file `tempo.yaml` is shared across the different components: `distributor`, `compactor`, `ingester`, `querier` and `queryFrontend`. This is set in the `tempo.configuration` value. Check the official [Tempo Grafana documentation](https://grafana.com/docs/tempo/latest/configuration/) for the list of possible configurations.

### Additional environment variables

In case you want to add extra environment variables (useful for advanced operations like custom init scripts), you can use the `extraEnvVars` property inside each of the subsections: `distributor`, `compactor`, `ingester`, `querier`, `queryFrontend` and `vulture`.

```yaml
compactor:
  extraEnvVars:
    - name: LOG_LEVEL
      value: error

distributor:
  extraEnvVars:
    - name: LOG_LEVEL
      value: error

ingester:
  extraEnvVars:
    - name: LOG_LEVEL
      value: error

querier:
  extraEnvVars:
    - name: LOG_LEVEL
      value: error

queryFrontend:
  extraEnvVars:
    - name: LOG_LEVEL
      value: error

vulture:
  extraEnvVars:
    - name: LOG_LEVEL
      value: error
```

Alternatively, you can use a ConfigMap or a Secret with the environment variables. To do so, use the `extraEnvVarsCM` or the `extraEnvVarsSecret` values.

### Sidecars

If additional containers are needed in the same pod as grafana-tempo (such as additional metrics or logging exporters), they can be defined using the `sidecars` parameter inside each of the subsections: `distributor`, `compactor`, `ingester`, `querier`, `queryFrontend` and `vulture` .

```yaml
sidecars:
- name: your-image-name
  image: your-image
  imagePullPolicy: Always
  ports:
  - name: portname
    containerPort: 1234
```

If these sidecars export extra ports, extra port definitions can be added using the `service.extraPorts` parameter (where available), as shown in the example below:

```yaml
service:
  extraPorts:
  - name: extraPort
    port: 11311
    targetPort: 11311
```

> NOTE: This Helm chart already includes sidecar containers for the Prometheus exporters (where applicable). These can be activated by adding the `--enable-metrics=true` parameter at deployment time. The `sidecars` parameter should therefore only be used for any extra sidecar containers.

If additional init containers are needed in the same pod, they can be defined using the `initContainers` parameter. Here is an example:

```yaml
initContainers:
  - name: your-image-name
    image: your-image
    imagePullPolicy: Always
    ports:
      - name: portname
        containerPort: 1234
```

Learn more about [sidecar containers](https://kubernetes.io/docs/concepts/workloads/pods/) and [init containers](https://kubernetes.io/docs/concepts/workloads/pods/init-containers/).

### Pod affinity

This chart allows you to set your custom affinity using the `affinity` parameter. Find more information about Pod affinity in the [kubernetes documentation](https://kubernetes.io/docs/concepts/configuration/assign-pod-node/#affinity-and-anti-affinity).

As an alternative, use one of the preset configurations for pod affinity, pod anti-affinity, and node affinity available at the [bitnami/common](https://github.com/bitnami/charts/tree/main/bitnami/common#affinities) chart. To do so, set the `podAffinityPreset`, `podAntiAffinityPreset`, or `nodeAffinityPreset` parameters inside each of the subsections: `distributor`, `compactor`, `ingester`, `querier`, `queryFrontend` and `vulture`.

### External cache support

You may want to have Grafana Tempo connect to an external Memcached rather than installing one inside your cluster. Typical reasons for this are to use a managed cache service, or to share a common cache server for all your applications. To achieve this, the chart allows you to specify credentials for an external database with the [`externalMemcached` parameter](#parameters). You should also disable the Memcached installation with the `memcached.enabled` option. Here is an example:

```console
memcached.enabled=false
externalMemcached.host=myexternalhost
externalMemcached.port=11211
```

## Persistence

The [Bitnami grafana-tempo](https://github.com/bitnami/containers/tree/main/bitnami/grafana-tempo) image stores the grafana-tempo `ingester` data at the `/bitnami` path of the container. Persistent Volume Claims are used to keep the data across deployments.

## Parameters

### Global parameters

| Name                                                  | Description                                                                                                                                                                                                                                                                                                                                                         | Value  |
| ----------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | ------ |
| `global.imageRegistry`                                | Global Docker image registry                                                                                                                                                                                                                                                                                                                                        | `""`   |
| `global.imagePullSecrets`                             | Global Docker registry secret names as an array                                                                                                                                                                                                                                                                                                                     | `[]`   |
| `global.defaultStorageClass`                          | Global default StorageClass for Persistent Volume(s)                                                                                                                                                                                                                                                                                                                | `""`   |
| `global.storageClass`                                 | DEPRECATED: use global.defaultStorageClass instead                                                                                                                                                                                                                                                                                                                  | `""`   |
| `global.compatibility.openshift.adaptSecurityContext` | Adapt the securityContext sections of the deployment to make them compatible with Openshift restricted-v2 SCC: remove runAsUser, runAsGroup and fsGroup and let the platform use their allowed default IDs. Possible values: auto (apply if the detected running cluster is Openshift), force (perform the adaptation always), disabled (do not perform adaptation) | `auto` |

### Common parameters

| Name                     | Description                                                                             | Value           |
| ------------------------ | --------------------------------------------------------------------------------------- | --------------- |
| `kubeVersion`            | Override Kubernetes version                                                             | `""`            |
| `nameOverride`           | String to partially override common.names.fullname                                      | `""`            |
| `fullnameOverride`       | String to fully override common.names.fullname                                          | `""`            |
| `commonLabels`           | Labels to add to all deployed objects                                                   | `{}`            |
| `commonAnnotations`      | Annotations to add to all deployed objects                                              | `{}`            |
| `clusterDomain`          | Kubernetes cluster domain name                                                          | `cluster.local` |
| `extraDeploy`            | Array of extra objects to deploy with the release                                       | `[]`            |
| `diagnosticMode.enabled` | Enable diagnostic mode (all probes will be disabled and the command will be overridden) | `false`         |
| `diagnosticMode.command` | Command to override all containers in the deployments/statefulsets                      | `["sleep"]`     |
| `diagnosticMode.args`    | Args to override all containers in the deployments/statefulsets                         | `["infinity"]`  |

### Common Grafana Tempo Parameters

| Name                                   | Description                                                                                                   | Value                           |
| -------------------------------------- | ------------------------------------------------------------------------------------------------------------- | ------------------------------- |
| `tempo.image.registry`                 | Grafana Tempo image registry                                                                                  | `REGISTRY_NAME`                 |
| `tempo.image.repository`               | Grafana Tempo image repository                                                                                | `REPOSITORY_NAME/grafana-tempo` |
| `tempo.image.digest`                   | Grafana Tempo image digest in the way sha256:aa.... Please note this parameter, if set, will override the tag | `""`                            |
| `tempo.image.pullPolicy`               | Grafana Tempo image pull policy                                                                               | `IfNotPresent`                  |
| `tempo.image.pullSecrets`              | Grafana Tempo image pull secrets                                                                              | `[]`                            |
| `tempo.memBallastSizeMbs`              | Tempo components memory ballast size in MB                                                                    | `1024`                          |
| `tempo.dataDir`                        | Tempo components data directory                                                                               | `/bitnami/grafana-tempo/data`   |
| `tempo.traces.jaeger.grpc`             | Enable Tempo to ingest Jaeger GRPC traces                                                                     | `true`                          |
| `tempo.traces.jaeger.thriftBinary`     | Enable Tempo to ingest Jaeger Thrift Binary traces                                                            | `false`                         |
| `tempo.traces.jaeger.thriftCompact`    | Enable Tempo to ingest Jaeger Thrift Compact traces                                                           | `false`                         |
| `tempo.traces.jaeger.thriftHttp`       | Enable Tempo to ingest Jaeger Thrift HTTP traces                                                              | `true`                          |
| `tempo.traces.otlp.http`               | Enable Tempo to ingest Open Telemetry HTTP traces                                                             | `false`                         |
| `tempo.traces.otlp.grpc`               | Enable Tempo to ingest Open Telemetry GRPC traces                                                             | `false`                         |
| `tempo.traces.opencensus`              | Enable Tempo to ingest Open Census traces                                                                     | `false`                         |
| `tempo.traces.zipkin`                  | Enable Tempo to ingest Zipkin traces                                                                          | `false`                         |
| `tempo.configuration`                  | Tempo components configuration                                                                                | `""`                            |
| `tempo.existingConfigmap`              | Name of a ConfigMap with the Tempo configuration                                                              | `""`                            |
| `tempo.overridesConfiguration`         | Tempo components overrides configuration settings                                                             | `""`                            |
| `tempo.existingOverridesConfigmap`     | Name of a ConfigMap with the tempo overrides configuration                                                    | `""`                            |
| `tempo.containerPorts.web`             | Tempo components web container port                                                                           | `3200`                          |
| `tempo.containerPorts.grpc`            | Tempo components GRPC container port                                                                          | `9095`                          |
| `tempo.containerPorts.gossipRing`      | Tempo components Gossip Ring container port                                                                   | `7946`                          |
| `tempo.gossipRing.service.ports.http`  | Gossip Ring HTTP headless service port                                                                        | `7946`                          |
| `tempo.gossipRing.service.annotations` | Additional custom annotations for Gossip Ring headless service                                                | `{}`                            |

### Compactor Deployment Parameters

| Name                                                          | Description                                                                                                                                                                                                                           | Value            |
| ------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | ---------------- |
| `compactor.enabled`                                           | Enable Compactor deployment                                                                                                                                                                                                           | `true`           |
| `compactor.extraEnvVars`                                      | Array with extra environment variables to add to compactor nodes                                                                                                                                                                      | `[]`             |
| `compactor.extraEnvVarsCM`                                    | Name of existing ConfigMap containing extra env vars for compactor nodes                                                                                                                                                              | `""`             |
| `compactor.extraEnvVarsSecret`                                | Name of existing Secret containing extra env vars for compactor nodes                                                                                                                                                                 | `""`             |
| `compactor.command`                                           | Override default container command (useful when using custom images)                                                                                                                                                                  | `[]`             |
| `compactor.args`                                              | Override default container args (useful when using custom images)                                                                                                                                                                     | `[]`             |
| `compactor.replicaCount`                                      | Number of Compactor replicas to deploy                                                                                                                                                                                                | `1`              |
| `compactor.livenessProbe.enabled`                             | Enable livenessProbe on Compactor nodes                                                                                                                                                                                               | `true`           |
| `compactor.livenessProbe.initialDelaySeconds`                 | Initial delay seconds for livenessProbe                                                                                                                                                                                               | `80`             |
| `compactor.livenessProbe.periodSeconds`                       | Period seconds for livenessProbe                                                                                                                                                                                                      | `10`             |
| `compactor.livenessProbe.timeoutSeconds`                      | Timeout seconds for livenessProbe                                                                                                                                                                                                     | `1`              |
| `compactor.livenessProbe.failureThreshold`                    | Failure threshold for livenessProbe                                                                                                                                                                                                   | `3`              |
| `compactor.livenessProbe.successThreshold`                    | Success threshold for livenessProbe                                                                                                                                                                                                   | `1`              |
| `compactor.readinessProbe.enabled`                            | Enable readinessProbe on Compactor nodes                                                                                                                                                                                              | `true`           |
| `compactor.readinessProbe.initialDelaySeconds`                | Initial delay seconds for readinessProbe                                                                                                                                                                                              | `80`             |
| `compactor.readinessProbe.periodSeconds`                      | Period seconds for readinessProbe                                                                                                                                                                                                     | `10`             |
| `compactor.readinessProbe.timeoutSeconds`                     | Timeout seconds for readinessProbe                                                                                                                                                                                                    | `1`              |
| `compactor.readinessProbe.failureThreshold`                   | Failure threshold for readinessProbe                                                                                                                                                                                                  | `3`              |
| `compactor.readinessProbe.successThreshold`                   | Success threshold for readinessProbe                                                                                                                                                                                                  | `1`              |
| `compactor.startupProbe.enabled`                              | Enable startupProbe on Compactor containers                                                                                                                                                                                           | `false`          |
| `compactor.startupProbe.initialDelaySeconds`                  | Initial delay seconds for startupProbe                                                                                                                                                                                                | `30`             |
| `compactor.startupProbe.periodSeconds`                        | Period seconds for startupProbe                                                                                                                                                                                                       | `10`             |
| `compactor.startupProbe.timeoutSeconds`                       | Timeout seconds for startupProbe                                                                                                                                                                                                      | `1`              |
| `compactor.startupProbe.failureThreshold`                     | Failure threshold for startupProbe                                                                                                                                                                                                    | `15`             |
| `compactor.startupProbe.successThreshold`                     | Success threshold for startupProbe                                                                                                                                                                                                    | `1`              |
| `compactor.customLivenessProbe`                               | Custom livenessProbe that overrides the default one                                                                                                                                                                                   | `{}`             |
| `compactor.customReadinessProbe`                              | Custom readinessProbe that overrides the default one                                                                                                                                                                                  | `{}`             |
| `compactor.customStartupProbe`                                | Custom startupProbe that overrides the default one                                                                                                                                                                                    | `{}`             |
| `compactor.resourcesPreset`                                   | Set container resources according to one common preset (allowed values: none, nano, micro, small, medium, large, xlarge, 2xlarge). This is ignored if compactor.resources is set (compactor.resources is recommended for production). | `nano`           |
| `compactor.resources`                                         | Set container requests and limits for different resources like CPU or memory (essential for production workloads)                                                                                                                     | `{}`             |
| `compactor.podSecurityContext.enabled`                        | Enabled Compactor pods' Security Context                                                                                                                                                                                              | `true`           |
| `compactor.podSecurityContext.fsGroupChangePolicy`            | Set filesystem group change policy                                                                                                                                                                                                    | `Always`         |
| `compactor.podSecurityContext.sysctls`                        | Set kernel settings using the sysctl interface                                                                                                                                                                                        | `[]`             |
| `compactor.podSecurityContext.supplementalGroups`             | Set filesystem extra groups                                                                                                                                                                                                           | `[]`             |
| `compactor.podSecurityContext.fsGroup`                        | Set Compactor pod's Security Context fsGroup                                                                                                                                                                                          | `1001`           |
| `compactor.containerSecurityContext.enabled`                  | Enabled containers' Security Context                                                                                                                                                                                                  | `true`           |
| `compactor.containerSecurityContext.seLinuxOptions`           | Set SELinux options in container                                                                                                                                                                                                      | `{}`             |
| `compactor.containerSecurityContext.runAsUser`                | Set containers' Security Context runAsUser                                                                                                                                                                                            | `1001`           |
| `compactor.containerSecurityContext.runAsGroup`               | Set containers' Security Context runAsGroup                                                                                                                                                                                           | `1001`           |
| `compactor.containerSecurityContext.runAsNonRoot`             | Set container's Security Context runAsNonRoot                                                                                                                                                                                         | `true`           |
| `compactor.containerSecurityContext.privileged`               | Set container's Security Context privileged                                                                                                                                                                                           | `false`          |
| `compactor.containerSecurityContext.readOnlyRootFilesystem`   | Set container's Security Context readOnlyRootFilesystem                                                                                                                                                                               | `true`           |
| `compactor.containerSecurityContext.allowPrivilegeEscalation` | Set container's Security Context allowPrivilegeEscalation                                                                                                                                                                             | `false`          |
| `compactor.containerSecurityContext.capabilities.drop`        | List of capabilities to be dropped                                                                                                                                                                                                    | `["ALL"]`        |
| `compactor.containerSecurityContext.seccompProfile.type`      | Set container's Security Context seccomp profile                                                                                                                                                                                      | `RuntimeDefault` |
| `compactor.lifecycleHooks`                                    | for the compactor container(s) to automate configuration before or after startup                                                                                                                                                      | `{}`             |
| `compactor.automountServiceAccountToken`                      | Mount Service Account token in pod                                                                                                                                                                                                    | `false`          |
| `compactor.hostAliases`                                       | compactor pods host aliases                                                                                                                                                                                                           | `[]`             |
| `compactor.podLabels`                                         | Extra labels for compactor pods                                                                                                                                                                                                       | `{}`             |
| `compactor.podAnnotations`                                    | Annotations for compactor pods                                                                                                                                                                                                        | `{}`             |
| `compactor.podAffinityPreset`                                 | Pod affinity preset. Ignored if `compactor.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                         | `""`             |
| `compactor.podAntiAffinityPreset`                             | Pod anti-affinity preset. Ignored if `compactor.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                    | `soft`           |
| `compactor.nodeAffinityPreset.type`                           | Node affinity preset type. Ignored if `compactor.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                   | `""`             |
| `compactor.nodeAffinityPreset.key`                            | Node label key to match. Ignored if `compactor.affinity` is set                                                                                                                                                                       | `""`             |
| `compactor.nodeAffinityPreset.values`                         | Node label values to match. Ignored if `compactor.affinity` is set                                                                                                                                                                    | `[]`             |
| `compactor.affinity`                                          | Affinity for Compactor pods assignment                                                                                                                                                                                                | `{}`             |
| `compactor.nodeSelector`                                      | Node labels for Compactor pods assignment                                                                                                                                                                                             | `{}`             |
| `compactor.tolerations`                                       | Tolerations for Compactor pods assignment                                                                                                                                                                                             | `[]`             |
| `compactor.topologySpreadConstraints`                         | Topology Spread Constraints for pod assignment spread across your cluster among failure-domains                                                                                                                                       | `[]`             |
| `compactor.priorityClassName`                                 | Compactor pods' priorityClassName                                                                                                                                                                                                     | `""`             |
| `compactor.schedulerName`                                     | Kubernetes pod scheduler registry                                                                                                                                                                                                     | `""`             |
| `compactor.updateStrategy.type`                               | Compactor statefulset strategy type                                                                                                                                                                                                   | `RollingUpdate`  |
| `compactor.updateStrategy.rollingUpdate`                      | Compactor statefulset rolling update configuration parameters                                                                                                                                                                         | `{}`             |
| `compactor.extraVolumes`                                      | Optionally specify extra list of additional volumes for the Compactor pod(s)                                                                                                                                                          | `[]`             |
| `compactor.extraVolumeMounts`                                 | Optionally specify extra list of additional volumeMounts for the Compactor container(s)                                                                                                                                               | `[]`             |
| `compactor.sidecars`                                          | Add additional sidecar containers to the Compactor pod(s)                                                                                                                                                                             | `[]`             |
| `compactor.initContainers`                                    | Add additional init containers to the Compactor pod(s)                                                                                                                                                                                | `[]`             |
| `compactor.pdb.create`                                        | Enable/disable a Pod Disruption Budget creation                                                                                                                                                                                       | `true`           |
| `compactor.pdb.minAvailable`                                  | Minimum number/percentage of pods that should remain scheduled                                                                                                                                                                        | `""`             |
| `compactor.pdb.maxUnavailable`                                | Maximum number/percentage of pods that may be made unavailable. Defaults to `1` if both `compactor.pdb.minAvailable` and `compactor.pdb.maxUnavailable` are empty.                                                                    | `""`             |
| `compactor.enableServiceLinks`                                | Whether information about services should be injected into pod's environment variable                                                                                                                                                 | `true`           |

### Compactor Traffic Exposure Parameters

| Name                                              | Description                                                                                                             | Value       |
| ------------------------------------------------- | ----------------------------------------------------------------------------------------------------------------------- | ----------- |
| `compactor.service.type`                          | Compactor service type                                                                                                  | `ClusterIP` |
| `compactor.service.ports.http`                    | Compactor HTTP service port                                                                                             | `3200`      |
| `compactor.service.ports.grpc`                    | Compactor GRPC service port                                                                                             | `9095`      |
| `compactor.service.nodePorts.http`                | Node port for HTTP                                                                                                      | `""`        |
| `compactor.service.sessionAffinity`               | Control where client requests go, to the same pod or round-robin                                                        | `None`      |
| `compactor.service.sessionAffinityConfig`         | Additional settings for the sessionAffinity                                                                             | `{}`        |
| `compactor.service.clusterIP`                     | Compactor service Cluster IP                                                                                            | `""`        |
| `compactor.service.loadBalancerIP`                | Compactor service Load Balancer IP                                                                                      | `""`        |
| `compactor.service.loadBalancerSourceRanges`      | Compactor service Load Balancer sources                                                                                 | `[]`        |
| `compactor.service.externalTrafficPolicy`         | Compactor service external traffic policy                                                                               | `Cluster`   |
| `compactor.service.annotations`                   | Additional custom annotations for Compactor service                                                                     | `{}`        |
| `compactor.service.extraPorts`                    | Extra ports to expose in the Compactor service                                                                          | `[]`        |
| `compactor.networkPolicy.enabled`                 | Specifies whether a NetworkPolicy should be created                                                                     | `true`      |
| `compactor.networkPolicy.allowExternal`           | Don't require server label for connections                                                                              | `true`      |
| `compactor.networkPolicy.allowExternalEgress`     | Allow the pod to access any range of port and all destinations.                                                         | `true`      |
| `compactor.networkPolicy.addExternalClientAccess` | Allow access from pods with client label set to "true". Ignored if `compactor.networkPolicy.allowExternal` is true.     | `true`      |
| `compactor.networkPolicy.extraIngress`            | Add extra ingress rules to the NetworkPolicy                                                                            | `[]`        |
| `compactor.networkPolicy.extraEgress`             | Add extra ingress rules to the NetworkPolicy                                                                            | `[]`        |
| `compactor.networkPolicy.ingressPodMatchLabels`   | Labels to match to allow traffic from other pods. Ignored if `compactor.networkPolicy.allowExternal` is true.           | `{}`        |
| `compactor.networkPolicy.ingressNSMatchLabels`    | Labels to match to allow traffic from other namespaces. Ignored if `compactor.networkPolicy.allowExternal` is true.     | `{}`        |
| `compactor.networkPolicy.ingressNSPodMatchLabels` | Pod labels to match to allow traffic from other namespaces. Ignored if `compactor.networkPolicy.allowExternal` is true. | `{}`        |

### Distributor Deployment Parameters

| Name                                                            | Description                                                                                                                                                                                                                               | Value            |
| --------------------------------------------------------------- | ----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | ---------------- |
| `distributor.extraEnvVars`                                      | Array with extra environment variables to add to distributor nodes                                                                                                                                                                        | `[]`             |
| `distributor.extraEnvVarsCM`                                    | Name of existing ConfigMap containing extra env vars for distributor nodes                                                                                                                                                                | `""`             |
| `distributor.extraEnvVarsSecret`                                | Name of existing Secret containing extra env vars for distributor nodes                                                                                                                                                                   | `""`             |
| `distributor.command`                                           | Override default container command (useful when using custom images)                                                                                                                                                                      | `[]`             |
| `distributor.args`                                              | Override default container args (useful when using custom images)                                                                                                                                                                         | `[]`             |
| `distributor.replicaCount`                                      | Number of Distributor replicas to deploy                                                                                                                                                                                                  | `1`              |
| `distributor.livenessProbe.enabled`                             | Enable livenessProbe on Distributor nodes                                                                                                                                                                                                 | `true`           |
| `distributor.livenessProbe.initialDelaySeconds`                 | Initial delay seconds for livenessProbe                                                                                                                                                                                                   | `10`             |
| `distributor.livenessProbe.periodSeconds`                       | Period seconds for livenessProbe                                                                                                                                                                                                          | `10`             |
| `distributor.livenessProbe.timeoutSeconds`                      | Timeout seconds for livenessProbe                                                                                                                                                                                                         | `1`              |
| `distributor.livenessProbe.failureThreshold`                    | Failure threshold for livenessProbe                                                                                                                                                                                                       | `3`              |
| `distributor.livenessProbe.successThreshold`                    | Success threshold for livenessProbe                                                                                                                                                                                                       | `1`              |
| `distributor.readinessProbe.enabled`                            | Enable readinessProbe on Distributor nodes                                                                                                                                                                                                | `true`           |
| `distributor.readinessProbe.initialDelaySeconds`                | Initial delay seconds for readinessProbe                                                                                                                                                                                                  | `10`             |
| `distributor.readinessProbe.periodSeconds`                      | Period seconds for readinessProbe                                                                                                                                                                                                         | `10`             |
| `distributor.readinessProbe.timeoutSeconds`                     | Timeout seconds for readinessProbe                                                                                                                                                                                                        | `1`              |
| `distributor.readinessProbe.failureThreshold`                   | Failure threshold for readinessProbe                                                                                                                                                                                                      | `3`              |
| `distributor.readinessProbe.successThreshold`                   | Success threshold for readinessProbe                                                                                                                                                                                                      | `1`              |
| `distributor.startupProbe.enabled`                              | Enable startupProbe on Distributor containers                                                                                                                                                                                             | `false`          |
| `distributor.startupProbe.initialDelaySeconds`                  | Initial delay seconds for startupProbe                                                                                                                                                                                                    | `30`             |
| `distributor.startupProbe.periodSeconds`                        | Period seconds for startupProbe                                                                                                                                                                                                           | `10`             |
| `distributor.startupProbe.timeoutSeconds`                       | Timeout seconds for startupProbe                                                                                                                                                                                                          | `1`              |
| `distributor.startupProbe.failureThreshold`                     | Failure threshold for startupProbe                                                                                                                                                                                                        | `15`             |
| `distributor.startupProbe.successThreshold`                     | Success threshold for startupProbe                                                                                                                                                                                                        | `1`              |
| `distributor.customLivenessProbe`                               | Custom livenessProbe that overrides the default one                                                                                                                                                                                       | `{}`             |
| `distributor.customReadinessProbe`                              | Custom readinessProbe that overrides the default one                                                                                                                                                                                      | `{}`             |
| `distributor.customStartupProbe`                                | Custom startupProbe that overrides the default one                                                                                                                                                                                        | `{}`             |
| `distributor.resourcesPreset`                                   | Set container resources according to one common preset (allowed values: none, nano, micro, small, medium, large, xlarge, 2xlarge). This is ignored if distributor.resources is set (distributor.resources is recommended for production). | `nano`           |
| `distributor.resources`                                         | Set container requests and limits for different resources like CPU or memory (essential for production workloads)                                                                                                                         | `{}`             |
| `distributor.podSecurityContext.enabled`                        | Enabled Distributor pods' Security Context                                                                                                                                                                                                | `true`           |
| `distributor.podSecurityContext.fsGroupChangePolicy`            | Set filesystem group change policy                                                                                                                                                                                                        | `Always`         |
| `distributor.podSecurityContext.sysctls`                        | Set kernel settings using the sysctl interface                                                                                                                                                                                            | `[]`             |
| `distributor.podSecurityContext.supplementalGroups`             | Set filesystem extra groups                                                                                                                                                                                                               | `[]`             |
| `distributor.podSecurityContext.fsGroup`                        | Set Distributor pod's Security Context fsGroup                                                                                                                                                                                            | `1001`           |
| `distributor.containerSecurityContext.enabled`                  | Enabled containers' Security Context                                                                                                                                                                                                      | `true`           |
| `distributor.containerSecurityContext.seLinuxOptions`           | Set SELinux options in container                                                                                                                                                                                                          | `{}`             |
| `distributor.containerSecurityContext.runAsUser`                | Set containers' Security Context runAsUser                                                                                                                                                                                                | `1001`           |
| `distributor.containerSecurityContext.runAsGroup`               | Set containers' Security Context runAsGroup                                                                                                                                                                                               | `1001`           |
| `distributor.containerSecurityContext.runAsNonRoot`             | Set container's Security Context runAsNonRoot                                                                                                                                                                                             | `true`           |
| `distributor.containerSecurityContext.privileged`               | Set container's Security Context privileged                                                                                                                                                                                               | `false`          |
| `distributor.containerSecurityContext.readOnlyRootFilesystem`   | Set container's Security Context readOnlyRootFilesystem                                                                                                                                                                                   | `true`           |
| `distributor.containerSecurityContext.allowPrivilegeEscalation` | Set container's Security Context allowPrivilegeEscalation                                                                                                                                                                                 | `false`          |
| `distributor.containerSecurityContext.capabilities.drop`        | List of capabilities to be dropped                                                                                                                                                                                                        | `["ALL"]`        |
| `distributor.containerSecurityContext.seccompProfile.type`      | Set container's Security Context seccomp profile                                                                                                                                                                                          | `RuntimeDefault` |
| `distributor.lifecycleHooks`                                    | for the distributor container(s) to automate configuration before or after startup                                                                                                                                                        | `{}`             |
| `distributor.automountServiceAccountToken`                      | Mount Service Account token in pod                                                                                                                                                                                                        | `false`          |
| `distributor.hostAliases`                                       | distributor pods host aliases                                                                                                                                                                                                             | `[]`             |
| `distributor.podLabels`                                         | Extra labels for distributor pods                                                                                                                                                                                                         | `{}`             |
| `distributor.podAnnotations`                                    | Annotations for distributor pods                                                                                                                                                                                                          | `{}`             |
| `distributor.podAffinityPreset`                                 | Pod affinity preset. Ignored if `distributor.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                           | `""`             |
| `distributor.podAntiAffinityPreset`                             | Pod anti-affinity preset. Ignored if `distributor.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                      | `soft`           |
| `distributor.nodeAffinityPreset.type`                           | Node affinity preset type. Ignored if `distributor.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                     | `""`             |
| `distributor.nodeAffinityPreset.key`                            | Node label key to match. Ignored if `distributor.affinity` is set                                                                                                                                                                         | `""`             |
| `distributor.nodeAffinityPreset.values`                         | Node label values to match. Ignored if `distributor.affinity` is set                                                                                                                                                                      | `[]`             |
| `distributor.affinity`                                          | Affinity for Distributor pods assignment                                                                                                                                                                                                  | `{}`             |
| `distributor.nodeSelector`                                      | Node labels for Distributor pods assignment                                                                                                                                                                                               | `{}`             |
| `distributor.tolerations`                                       | Tolerations for Distributor pods assignment                                                                                                                                                                                               | `[]`             |
| `distributor.topologySpreadConstraints`                         | Topology Spread Constraints for pod assignment spread across your cluster among failure-domains                                                                                                                                           | `[]`             |
| `distributor.priorityClassName`                                 | Distributor pods' priorityClassName                                                                                                                                                                                                       | `""`             |
| `distributor.schedulerName`                                     | Kubernetes pod scheduler registry                                                                                                                                                                                                         | `""`             |
| `distributor.updateStrategy.type`                               | Distributor statefulset strategy type                                                                                                                                                                                                     | `RollingUpdate`  |
| `distributor.updateStrategy.rollingUpdate`                      | Distributor statefulset rolling update configuration parameters                                                                                                                                                                           | `{}`             |
| `distributor.extraVolumes`                                      | Optionally specify extra list of additional volumes for the Distributor pod(s)                                                                                                                                                            | `[]`             |
| `distributor.extraVolumeMounts`                                 | Optionally specify extra list of additional volumeMounts for the Distributor container(s)                                                                                                                                                 | `[]`             |
| `distributor.sidecars`                                          | Add additional sidecar containers to the Distributor pod(s)                                                                                                                                                                               | `[]`             |
| `distributor.initContainers`                                    | Add additional init containers to the Distributor pod(s)                                                                                                                                                                                  | `[]`             |
| `distributor.pdb.create`                                        | Enable/disable a Pod Disruption Budget creation                                                                                                                                                                                           | `true`           |
| `distributor.pdb.minAvailable`                                  | Minimum number/percentage of pods that should remain scheduled                                                                                                                                                                            | `""`             |
| `distributor.pdb.maxUnavailable`                                | Maximum number/percentage of pods that may be made unavailable. Defaults to `1` if both `distributor.pdb.minAvailable` and `distributor.pdb.maxUnavailable` are empty.                                                                    | `""`             |
| `distributor.enableServiceLinks`                                | Whether information about services should be injected into pod's environment variable                                                                                                                                                     | `true`           |

### Distributor Traffic Exposure Parameters

| Name                                                | Description                                                                                                               | Value       |
| --------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------- | ----------- |
| `distributor.service.type`                          | Distributor service type                                                                                                  | `ClusterIP` |
| `distributor.service.ports.http`                    | Distributor HTTP service port                                                                                             | `3200`      |
| `distributor.service.ports.grpc`                    | Distributor GRPC service port                                                                                             | `9095`      |
| `distributor.service.nodePorts.http`                | Node port for HTTP                                                                                                        | `""`        |
| `distributor.service.nodePorts.grpc`                | Node port for GRPC                                                                                                        | `""`        |
| `distributor.service.sessionAffinity`               | Control where client requests go, to the same pod or round-robin                                                          | `None`      |
| `distributor.service.sessionAffinityConfig`         | Additional settings for the sessionAffinity                                                                               | `{}`        |
| `distributor.service.clusterIP`                     | Distributor service Cluster IP                                                                                            | `""`        |
| `distributor.service.loadBalancerIP`                | Distributor service Load Balancer IP                                                                                      | `""`        |
| `distributor.service.loadBalancerSourceRanges`      | Distributor service Load Balancer sources                                                                                 | `[]`        |
| `distributor.service.externalTrafficPolicy`         | Distributor service external traffic policy                                                                               | `Cluster`   |
| `distributor.service.annotations`                   | Additional custom annotations for Distributor service                                                                     | `{}`        |
| `distributor.service.extraPorts`                    | Extra ports to expose in the Distributor service                                                                          | `[]`        |
| `distributor.networkPolicy.enabled`                 | Specifies whether a NetworkPolicy should be created                                                                       | `true`      |
| `distributor.networkPolicy.allowExternal`           | Don't require server label for connections                                                                                | `true`      |
| `distributor.networkPolicy.allowExternalEgress`     | Allow the pod to access any range of port and all destinations.                                                           | `true`      |
| `distributor.networkPolicy.addExternalClientAccess` | Allow access from pods with client label set to "true". Ignored if `distributor.networkPolicy.allowExternal` is true.     | `true`      |
| `distributor.networkPolicy.extraIngress`            | Add extra ingress rules to the NetworkPolicy                                                                              | `[]`        |
| `distributor.networkPolicy.extraEgress`             | Add extra ingress rules to the NetworkPolicy                                                                              | `[]`        |
| `distributor.networkPolicy.ingressPodMatchLabels`   | Labels to match to allow traffic from other pods. Ignored if `distributor.networkPolicy.allowExternal` is true.           | `{}`        |
| `distributor.networkPolicy.ingressNSMatchLabels`    | Labels to match to allow traffic from other namespaces. Ignored if `distributor.networkPolicy.allowExternal` is true.     | `{}`        |
| `distributor.networkPolicy.ingressNSPodMatchLabels` | Pod labels to match to allow traffic from other namespaces. Ignored if `distributor.networkPolicy.allowExternal` is true. | `{}`        |

### Metrics Generator Deployment Parameters

| Name                                                                 | Description                                                                                                                                                                                                                                         | Value            |
| -------------------------------------------------------------------- | --------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | ---------------- |
| `metricsGenerator.remoteWrite`                                       | remoteWrite configuration for metricsGenerator                                                                                                                                                                                                      | `[]`             |
| `metricsGenerator.extraEnvVars`                                      | Array with extra environment variables to add to metricsGenerator nodes                                                                                                                                                                             | `[]`             |
| `metricsGenerator.extraEnvVarsCM`                                    | Name of existing ConfigMap containing extra env vars for metricsGenerator nodes                                                                                                                                                                     | `""`             |
| `metricsGenerator.extraEnvVarsSecret`                                | Name of existing Secret containing extra env vars for metricsGenerator nodes                                                                                                                                                                        | `""`             |
| `metricsGenerator.command`                                           | Override default container command (useful when using custom images)                                                                                                                                                                                | `[]`             |
| `metricsGenerator.args`                                              | Override default container args (useful when using custom images)                                                                                                                                                                                   | `[]`             |
| `metricsGenerator.replicaCount`                                      | Number of metricsGenerator replicas to deploy                                                                                                                                                                                                       | `1`              |
| `metricsGenerator.livenessProbe.enabled`                             | Enable livenessProbe on metricsGenerator nodes                                                                                                                                                                                                      | `true`           |
| `metricsGenerator.livenessProbe.initialDelaySeconds`                 | Initial delay seconds for livenessProbe                                                                                                                                                                                                             | `10`             |
| `metricsGenerator.livenessProbe.periodSeconds`                       | Period seconds for livenessProbe                                                                                                                                                                                                                    | `10`             |
| `metricsGenerator.livenessProbe.timeoutSeconds`                      | Timeout seconds for livenessProbe                                                                                                                                                                                                                   | `1`              |
| `metricsGenerator.livenessProbe.failureThreshold`                    | Failure threshold for livenessProbe                                                                                                                                                                                                                 | `3`              |
| `metricsGenerator.livenessProbe.successThreshold`                    | Success threshold for livenessProbe                                                                                                                                                                                                                 | `1`              |
| `metricsGenerator.readinessProbe.enabled`                            | Enable readinessProbe on metricsGenerator nodes                                                                                                                                                                                                     | `true`           |
| `metricsGenerator.readinessProbe.initialDelaySeconds`                | Initial delay seconds for readinessProbe                                                                                                                                                                                                            | `10`             |
| `metricsGenerator.readinessProbe.periodSeconds`                      | Period seconds for readinessProbe                                                                                                                                                                                                                   | `10`             |
| `metricsGenerator.readinessProbe.timeoutSeconds`                     | Timeout seconds for readinessProbe                                                                                                                                                                                                                  | `1`              |
| `metricsGenerator.readinessProbe.failureThreshold`                   | Failure threshold for readinessProbe                                                                                                                                                                                                                | `3`              |
| `metricsGenerator.readinessProbe.successThreshold`                   | Success threshold for readinessProbe                                                                                                                                                                                                                | `1`              |
| `metricsGenerator.startupProbe.enabled`                              | Enable startupProbe on metricsGenerator containers                                                                                                                                                                                                  | `false`          |
| `metricsGenerator.startupProbe.initialDelaySeconds`                  | Initial delay seconds for startupProbe                                                                                                                                                                                                              | `30`             |
| `metricsGenerator.startupProbe.periodSeconds`                        | Period seconds for startupProbe                                                                                                                                                                                                                     | `10`             |
| `metricsGenerator.startupProbe.timeoutSeconds`                       | Timeout seconds for startupProbe                                                                                                                                                                                                                    | `1`              |
| `metricsGenerator.startupProbe.failureThreshold`                     | Failure threshold for startupProbe                                                                                                                                                                                                                  | `15`             |
| `metricsGenerator.startupProbe.successThreshold`                     | Success threshold for startupProbe                                                                                                                                                                                                                  | `1`              |
| `metricsGenerator.customLivenessProbe`                               | Custom livenessProbe that overrides the default one                                                                                                                                                                                                 | `{}`             |
| `metricsGenerator.customReadinessProbe`                              | Custom readinessProbe that overrides the default one                                                                                                                                                                                                | `{}`             |
| `metricsGenerator.customStartupProbe`                                | Custom startupProbe that overrides the default one                                                                                                                                                                                                  | `{}`             |
| `metricsGenerator.resourcesPreset`                                   | Set container resources according to one common preset (allowed values: none, nano, micro, small, medium, large, xlarge, 2xlarge). This is ignored if metricsGenerator.resources is set (metricsGenerator.resources is recommended for production). | `nano`           |
| `metricsGenerator.resources`                                         | Set container requests and limits for different resources like CPU or memory (essential for production workloads)                                                                                                                                   | `{}`             |
| `metricsGenerator.podSecurityContext.enabled`                        | Enabled metricsGenerator pods' Security Context                                                                                                                                                                                                     | `true`           |
| `metricsGenerator.podSecurityContext.fsGroupChangePolicy`            | Set filesystem group change policy                                                                                                                                                                                                                  | `Always`         |
| `metricsGenerator.podSecurityContext.sysctls`                        | Set kernel settings using the sysctl interface                                                                                                                                                                                                      | `[]`             |
| `metricsGenerator.podSecurityContext.supplementalGroups`             | Set filesystem extra groups                                                                                                                                                                                                                         | `[]`             |
| `metricsGenerator.podSecurityContext.fsGroup`                        | Set metricsGenerator pod's Security Context fsGroup                                                                                                                                                                                                 | `1001`           |
| `metricsGenerator.containerSecurityContext.enabled`                  | Enabled containers' Security Context                                                                                                                                                                                                                | `true`           |
| `metricsGenerator.containerSecurityContext.seLinuxOptions`           | Set SELinux options in container                                                                                                                                                                                                                    | `{}`             |
| `metricsGenerator.containerSecurityContext.runAsUser`                | Set containers' Security Context runAsUser                                                                                                                                                                                                          | `1001`           |
| `metricsGenerator.containerSecurityContext.runAsGroup`               | Set containers' Security Context runAsGroup                                                                                                                                                                                                         | `1001`           |
| `metricsGenerator.containerSecurityContext.runAsNonRoot`             | Set container's Security Context runAsNonRoot                                                                                                                                                                                                       | `true`           |
| `metricsGenerator.containerSecurityContext.privileged`               | Set container's Security Context privileged                                                                                                                                                                                                         | `false`          |
| `metricsGenerator.containerSecurityContext.readOnlyRootFilesystem`   | Set container's Security Context readOnlyRootFilesystem                                                                                                                                                                                             | `true`           |
| `metricsGenerator.containerSecurityContext.allowPrivilegeEscalation` | Set container's Security Context allowPrivilegeEscalation                                                                                                                                                                                           | `false`          |
| `metricsGenerator.containerSecurityContext.capabilities.drop`        | List of capabilities to be dropped                                                                                                                                                                                                                  | `["ALL"]`        |
| `metricsGenerator.containerSecurityContext.seccompProfile.type`      | Set container's Security Context seccomp profile                                                                                                                                                                                                    | `RuntimeDefault` |
| `metricsGenerator.lifecycleHooks`                                    | for the metricsGenerator container(s) to automate configuration before or after startup                                                                                                                                                             | `{}`             |
| `metricsGenerator.automountServiceAccountToken`                      | Mount Service Account token in pod                                                                                                                                                                                                                  | `false`          |
| `metricsGenerator.hostAliases`                                       | metricsGenerator pods host aliases                                                                                                                                                                                                                  | `[]`             |
| `metricsGenerator.podLabels`                                         | Extra labels for metricsGenerator pods                                                                                                                                                                                                              | `{}`             |
| `metricsGenerator.podAnnotations`                                    | Annotations for metricsGenerator pods                                                                                                                                                                                                               | `{}`             |
| `metricsGenerator.podAffinityPreset`                                 | Pod affinity preset. Ignored if `metricsGenerator.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                                | `""`             |
| `metricsGenerator.podAntiAffinityPreset`                             | Pod anti-affinity preset. Ignored if `metricsGenerator.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                           | `soft`           |
| `metricsGenerator.nodeAffinityPreset.type`                           | Node affinity preset type. Ignored if `metricsGenerator.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                          | `""`             |
| `metricsGenerator.nodeAffinityPreset.key`                            | Node label key to match. Ignored if `metricsGenerator.affinity` is set                                                                                                                                                                              | `""`             |
| `metricsGenerator.nodeAffinityPreset.values`                         | Node label values to match. Ignored if `metricsGenerator.affinity` is set                                                                                                                                                                           | `[]`             |
| `metricsGenerator.affinity`                                          | Affinity for metricsGenerator pods assignment                                                                                                                                                                                                       | `{}`             |
| `metricsGenerator.nodeSelector`                                      | Node labels for metricsGenerator pods assignment                                                                                                                                                                                                    | `{}`             |
| `metricsGenerator.tolerations`                                       | Tolerations for metricsGenerator pods assignment                                                                                                                                                                                                    | `[]`             |
| `metricsGenerator.topologySpreadConstraints`                         | Topology Spread Constraints for pod assignment spread across your cluster among failure-domains                                                                                                                                                     | `{}`             |
| `metricsGenerator.priorityClassName`                                 | metricsGenerator pods' priorityClassName                                                                                                                                                                                                            | `""`             |
| `metricsGenerator.schedulerName`                                     | Kubernetes pod scheduler registry                                                                                                                                                                                                                   | `""`             |
| `metricsGenerator.updateStrategy.type`                               | metricsGenerator statefulset strategy type                                                                                                                                                                                                          | `RollingUpdate`  |
| `metricsGenerator.updateStrategy.rollingUpdate`                      | metricsGenerator statefulset rolling update configuration parameters                                                                                                                                                                                | `{}`             |
| `metricsGenerator.extraVolumes`                                      | Optionally specify extra list of additional volumes for the metricsGenerator pod(s)                                                                                                                                                                 | `[]`             |
| `metricsGenerator.extraVolumeMounts`                                 | Optionally specify extra list of additional volumeMounts for the metricsGenerator container(s)                                                                                                                                                      | `[]`             |
| `metricsGenerator.sidecars`                                          | Add additional sidecar containers to the metricsGenerator pod(s)                                                                                                                                                                                    | `[]`             |
| `metricsGenerator.initContainers`                                    | Add additional init containers to the metricsGenerator pod(s)                                                                                                                                                                                       | `[]`             |
| `metricsGenerator.pdb.create`                                        | Enable/disable a Pod Disruption Budget creation                                                                                                                                                                                                     | `true`           |
| `metricsGenerator.pdb.minAvailable`                                  | Minimum number/percentage of pods that should remain scheduled                                                                                                                                                                                      | `""`             |
| `metricsGenerator.pdb.maxUnavailable`                                | Maximum number/percentage of pods that may be made unavailable. Defaults to `1` if both `metricsGenerator.pdb.minAvailable` and `metricsGenerator.pdb.maxUnavailable` are empty.                                                                    | `""`             |
| `metricsGenerator.enableServiceLinks`                                | Whether information about services should be injected into pod's environment variable                                                                                                                                                               | `true`           |

### Metrics Generator Traffic Exposure Parameters

| Name                                                     | Description                                                                                                                    | Value       |
| -------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------ | ----------- |
| `metricsGenerator.service.type`                          | metricsGenerator service type                                                                                                  | `ClusterIP` |
| `metricsGenerator.service.ports.http`                    | metricsGenerator HTTP service port                                                                                             | `3200`      |
| `metricsGenerator.service.ports.grpc`                    | metricsGenerator GRPC service port                                                                                             | `9095`      |
| `metricsGenerator.service.nodePorts.http`                | Node port for HTTP                                                                                                             | `""`        |
| `metricsGenerator.service.nodePorts.grpc`                | Node port for GRPC                                                                                                             | `""`        |
| `metricsGenerator.service.sessionAffinity`               | Control where client requests go, to the same pod or round-robin                                                               | `None`      |
| `metricsGenerator.service.clusterIP`                     | metricsGenerator service Cluster IP                                                                                            | `""`        |
| `metricsGenerator.service.loadBalancerIP`                | metricsGenerator service Load Balancer IP                                                                                      | `""`        |
| `metricsGenerator.service.loadBalancerSourceRanges`      | metricsGenerator service Load Balancer sources                                                                                 | `[]`        |
| `metricsGenerator.service.externalTrafficPolicy`         | metricsGenerator service external traffic policy                                                                               | `Cluster`   |
| `metricsGenerator.service.annotations`                   | Additional custom annotations for metricsGenerator service                                                                     | `{}`        |
| `metricsGenerator.service.extraPorts`                    | Extra ports to expose in the metricsGenerator service                                                                          | `[]`        |
| `metricsGenerator.networkPolicy.enabled`                 | Specifies whether a NetworkPolicy should be created                                                                            | `true`      |
| `metricsGenerator.networkPolicy.allowExternal`           | Don't require server label for connections                                                                                     | `true`      |
| `metricsGenerator.networkPolicy.addExternalClientAccess` | Allow access from pods with client label set to "true". Ignored if `metricsGenerator.networkPolicy.allowExternal` is true.     | `true`      |
| `metricsGenerator.networkPolicy.allowExternalEgress`     | Allow the pod to access any range of port and all destinations.                                                                | `true`      |
| `metricsGenerator.networkPolicy.extraIngress`            | Add extra ingress rules to the NetworkPolicy                                                                                   | `[]`        |
| `metricsGenerator.networkPolicy.extraEgress`             | Add extra ingress rules to the NetworkPolicy                                                                                   | `[]`        |
| `metricsGenerator.networkPolicy.ingressPodMatchLabels`   | Labels to match to allow traffic from other pods. Ignored if `metricsGenerator.networkPolicy.allowExternal` is true.           | `{}`        |
| `metricsGenerator.networkPolicy.ingressNSMatchLabels`    | Labels to match to allow traffic from other namespaces. Ignored if `metricsGenerator.networkPolicy.allowExternal` is true.     | `{}`        |
| `metricsGenerator.networkPolicy.ingressNSPodMatchLabels` | Pod labels to match to allow traffic from other namespaces. Ignored if `metricsGenerator.networkPolicy.allowExternal` is true. | `{}`        |

### Ingester Deployment Parameters

| Name                                                         | Description                                                                                                                                                                                                                         | Value            |
| ------------------------------------------------------------ | ----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | ---------------- |
| `ingester.extraEnvVars`                                      | Array with extra environment variables to add to ingester nodes                                                                                                                                                                     | `[]`             |
| `ingester.extraEnvVarsCM`                                    | Name of existing ConfigMap containing extra env vars for ingester nodes                                                                                                                                                             | `""`             |
| `ingester.extraEnvVarsSecret`                                | Name of existing Secret containing extra env vars for ingester nodes                                                                                                                                                                | `""`             |
| `ingester.command`                                           | Override default container command (useful when using custom images)                                                                                                                                                                | `[]`             |
| `ingester.args`                                              | Override default container args (useful when using custom images)                                                                                                                                                                   | `[]`             |
| `ingester.replicaCount`                                      | Number of Ingester replicas to deploy                                                                                                                                                                                               | `1`              |
| `ingester.livenessProbe.enabled`                             | Enable livenessProbe on Ingester nodes                                                                                                                                                                                              | `true`           |
| `ingester.livenessProbe.initialDelaySeconds`                 | Initial delay seconds for livenessProbe                                                                                                                                                                                             | `10`             |
| `ingester.livenessProbe.periodSeconds`                       | Period seconds for livenessProbe                                                                                                                                                                                                    | `10`             |
| `ingester.livenessProbe.timeoutSeconds`                      | Timeout seconds for livenessProbe                                                                                                                                                                                                   | `1`              |
| `ingester.livenessProbe.failureThreshold`                    | Failure threshold for livenessProbe                                                                                                                                                                                                 | `3`              |
| `ingester.livenessProbe.successThreshold`                    | Success threshold for livenessProbe                                                                                                                                                                                                 | `1`              |
| `ingester.readinessProbe.enabled`                            | Enable readinessProbe on Ingester nodes                                                                                                                                                                                             | `true`           |
| `ingester.readinessProbe.initialDelaySeconds`                | Initial delay seconds for readinessProbe                                                                                                                                                                                            | `10`             |
| `ingester.readinessProbe.periodSeconds`                      | Period seconds for readinessProbe                                                                                                                                                                                                   | `10`             |
| `ingester.readinessProbe.timeoutSeconds`                     | Timeout seconds for readinessProbe                                                                                                                                                                                                  | `1`              |
| `ingester.readinessProbe.failureThreshold`                   | Failure threshold for readinessProbe                                                                                                                                                                                                | `3`              |
| `ingester.readinessProbe.successThreshold`                   | Success threshold for readinessProbe                                                                                                                                                                                                | `1`              |
| `ingester.startupProbe.enabled`                              | Enable startupProbe on Ingester containers                                                                                                                                                                                          | `false`          |
| `ingester.startupProbe.initialDelaySeconds`                  | Initial delay seconds for startupProbe                                                                                                                                                                                              | `30`             |
| `ingester.startupProbe.periodSeconds`                        | Period seconds for startupProbe                                                                                                                                                                                                     | `10`             |
| `ingester.startupProbe.timeoutSeconds`                       | Timeout seconds for startupProbe                                                                                                                                                                                                    | `1`              |
| `ingester.startupProbe.failureThreshold`                     | Failure threshold for startupProbe                                                                                                                                                                                                  | `15`             |
| `ingester.startupProbe.successThreshold`                     | Success threshold for startupProbe                                                                                                                                                                                                  | `1`              |
| `ingester.customLivenessProbe`                               | Custom livenessProbe that overrides the default one                                                                                                                                                                                 | `{}`             |
| `ingester.customReadinessProbe`                              | Custom readinessProbe that overrides the default one                                                                                                                                                                                | `{}`             |
| `ingester.customStartupProbe`                                | Custom startupProbe that overrides the default one                                                                                                                                                                                  | `{}`             |
| `ingester.lifecycleHooks`                                    | for the ingester container(s) to automate configuration before or after startup                                                                                                                                                     | `{}`             |
| `ingester.resourcesPreset`                                   | Set container resources according to one common preset (allowed values: none, nano, micro, small, medium, large, xlarge, 2xlarge). This is ignored if ingester.resources is set (ingester.resources is recommended for production). | `nano`           |
| `ingester.resources`                                         | Set container requests and limits for different resources like CPU or memory (essential for production workloads)                                                                                                                   | `{}`             |
| `ingester.podSecurityContext.enabled`                        | Enabled Ingester pods' Security Context                                                                                                                                                                                             | `true`           |
| `ingester.podSecurityContext.fsGroupChangePolicy`            | Set filesystem group change policy                                                                                                                                                                                                  | `Always`         |
| `ingester.podSecurityContext.sysctls`                        | Set kernel settings using the sysctl interface                                                                                                                                                                                      | `[]`             |
| `ingester.podSecurityContext.supplementalGroups`             | Set filesystem extra groups                                                                                                                                                                                                         | `[]`             |
| `ingester.podSecurityContext.fsGroup`                        | Set Ingester pod's Security Context fsGroup                                                                                                                                                                                         | `1001`           |
| `ingester.containerSecurityContext.enabled`                  | Enabled containers' Security Context                                                                                                                                                                                                | `true`           |
| `ingester.containerSecurityContext.seLinuxOptions`           | Set SELinux options in container                                                                                                                                                                                                    | `{}`             |
| `ingester.containerSecurityContext.runAsUser`                | Set containers' Security Context runAsUser                                                                                                                                                                                          | `1001`           |
| `ingester.containerSecurityContext.runAsGroup`               | Set containers' Security Context runAsGroup                                                                                                                                                                                         | `1001`           |
| `ingester.containerSecurityContext.runAsNonRoot`             | Set container's Security Context runAsNonRoot                                                                                                                                                                                       | `true`           |
| `ingester.containerSecurityContext.privileged`               | Set container's Security Context privileged                                                                                                                                                                                         | `false`          |
| `ingester.containerSecurityContext.readOnlyRootFilesystem`   | Set container's Security Context readOnlyRootFilesystem                                                                                                                                                                             | `true`           |
| `ingester.containerSecurityContext.allowPrivilegeEscalation` | Set container's Security Context allowPrivilegeEscalation                                                                                                                                                                           | `false`          |
| `ingester.containerSecurityContext.capabilities.drop`        | List of capabilities to be dropped                                                                                                                                                                                                  | `["ALL"]`        |
| `ingester.containerSecurityContext.seccompProfile.type`      | Set container's Security Context seccomp profile                                                                                                                                                                                    | `RuntimeDefault` |
| `ingester.automountServiceAccountToken`                      | Mount Service Account token in pod                                                                                                                                                                                                  | `false`          |
| `ingester.hostAliases`                                       | ingester pods host aliases                                                                                                                                                                                                          | `[]`             |
| `ingester.podLabels`                                         | Extra labels for ingester pods                                                                                                                                                                                                      | `{}`             |
| `ingester.podAnnotations`                                    | Annotations for ingester pods                                                                                                                                                                                                       | `{}`             |
| `ingester.podAffinityPreset`                                 | Pod affinity preset. Ignored if `ingester.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                        | `""`             |
| `ingester.podAntiAffinityPreset`                             | Pod anti-affinity preset. Ignored if `ingester.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                   | `soft`           |
| `ingester.nodeAffinityPreset.type`                           | Node affinity preset type. Ignored if `ingester.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                  | `""`             |
| `ingester.nodeAffinityPreset.key`                            | Node label key to match. Ignored if `ingester.affinity` is set                                                                                                                                                                      | `""`             |
| `ingester.nodeAffinityPreset.values`                         | Node label values to match. Ignored if `ingester.affinity` is set                                                                                                                                                                   | `[]`             |
| `ingester.affinity`                                          | Affinity for ingester pods assignment                                                                                                                                                                                               | `{}`             |
| `ingester.nodeSelector`                                      | Node labels for Ingester pods assignment                                                                                                                                                                                            | `{}`             |
| `ingester.tolerations`                                       | Tolerations for Ingester pods assignment                                                                                                                                                                                            | `[]`             |
| `ingester.topologySpreadConstraints`                         | Topology Spread Constraints for pod assignment spread across your cluster among failure-domains                                                                                                                                     | `[]`             |
| `ingester.priorityClassName`                                 | Ingester pods' priorityClassName                                                                                                                                                                                                    | `""`             |
| `ingester.schedulerName`                                     | Kubernetes pod scheduler registry                                                                                                                                                                                                   | `""`             |
| `ingester.updateStrategy.type`                               | Ingester statefulset strategy type                                                                                                                                                                                                  | `RollingUpdate`  |
| `ingester.updateStrategy.rollingUpdate`                      | Ingester statefulset rolling update configuration parameters                                                                                                                                                                        | `{}`             |
| `ingester.extraVolumes`                                      | Optionally specify extra list of additional volumes for the Ingester pod(s)                                                                                                                                                         | `[]`             |
| `ingester.extraVolumeMounts`                                 | Optionally specify extra list of additional volumeMounts for the ingester container(s)                                                                                                                                              | `[]`             |
| `ingester.sidecars`                                          | Add additional sidecar containers to the Ingester pod(s)                                                                                                                                                                            | `[]`             |
| `ingester.initContainers`                                    | Add additional init containers to the Ingester pod(s)                                                                                                                                                                               | `[]`             |
| `ingester.pdb.create`                                        | Enable/disable a Pod Disruption Budget creation                                                                                                                                                                                     | `true`           |
| `ingester.pdb.minAvailable`                                  | Minimum number/percentage of pods that should remain scheduled                                                                                                                                                                      | `""`             |
| `ingester.pdb.maxUnavailable`                                | Maximum number/percentage of pods that may be made unavailable. Defaults to `1` if both `ingester.pdb.minAvailable` and `ingester.pdb.maxUnavailable` are empty.                                                                    | `""`             |
| `ingester.enableServiceLinks`                                | Whether information about services should be injected into pod's environment variable                                                                                                                                               | `true`           |

### Ingester Persistence Parameters

| Name                                 | Description                                                             | Value               |
| ------------------------------------ | ----------------------------------------------------------------------- | ------------------- |
| `ingester.persistence.enabled`       | Enable persistence in Ingester instances                                | `true`              |
| `ingester.persistence.existingClaim` | Name of an existing PVC to use                                          | `""`                |
| `ingester.persistence.storageClass`  | PVC Storage Class for Memcached data volume                             | `""`                |
| `ingester.persistence.subPath`       | The subdirectory of the volume to mount to                              | `""`                |
| `ingester.persistence.accessModes`   | PVC Access modes                                                        | `["ReadWriteOnce"]` |
| `ingester.persistence.size`          | PVC Storage Request for Memcached data volume                           | `8Gi`               |
| `ingester.persistence.annotations`   | Additional PVC annotations                                              | `{}`                |
| `ingester.persistence.selector`      | Selector to match an existing Persistent Volume for Ingester's data PVC | `{}`                |

### Ingester Traffic Exposure Parameters

| Name                                             | Description                                                                                                            | Value       |
| ------------------------------------------------ | ---------------------------------------------------------------------------------------------------------------------- | ----------- |
| `ingester.service.type`                          | Ingester service type                                                                                                  | `ClusterIP` |
| `ingester.service.ports.http`                    | Ingester HTTP service port                                                                                             | `3200`      |
| `ingester.service.ports.grpc`                    | Ingester GRPC service port                                                                                             | `9095`      |
| `ingester.service.nodePorts.http`                | Node port for HTTP                                                                                                     | `""`        |
| `ingester.service.nodePorts.grpc`                | Node port for GRPC                                                                                                     | `""`        |
| `ingester.service.sessionAffinity`               | Control where client requests go, to the same pod or round-robin                                                       | `None`      |
| `ingester.service.sessionAffinityConfig`         | Additional settings for the sessionAffinity                                                                            | `{}`        |
| `ingester.service.clusterIP`                     | Ingester service Cluster IP                                                                                            | `""`        |
| `ingester.service.loadBalancerIP`                | Ingester service Load Balancer IP                                                                                      | `""`        |
| `ingester.service.loadBalancerSourceRanges`      | Ingester service Load Balancer sources                                                                                 | `[]`        |
| `ingester.service.externalTrafficPolicy`         | Ingester service external traffic policy                                                                               | `Cluster`   |
| `ingester.service.annotations`                   | Additional custom annotations for Ingester service                                                                     | `{}`        |
| `ingester.service.extraPorts`                    | Extra ports to expose in the Ingester service                                                                          | `[]`        |
| `ingester.networkPolicy.enabled`                 | Specifies whether a NetworkPolicy should be created                                                                    | `true`      |
| `ingester.networkPolicy.allowExternal`           | Don't require server label for connections                                                                             | `true`      |
| `ingester.networkPolicy.allowExternalEgress`     | Allow the pod to access any range of port and all destinations.                                                        | `true`      |
| `ingester.networkPolicy.addExternalClientAccess` | Allow access from pods with client label set to "true". Ignored if `ingester.networkPolicy.allowExternal` is true.     | `true`      |
| `ingester.networkPolicy.extraIngress`            | Add extra ingress rules to the NetworkPolicy                                                                           | `[]`        |
| `ingester.networkPolicy.extraEgress`             | Add extra ingress rules to the NetworkPolicy                                                                           | `[]`        |
| `ingester.networkPolicy.ingressPodMatchLabels`   | Labels to match to allow traffic from other pods. Ignored if `ingester.networkPolicy.allowExternal` is true.           | `{}`        |
| `ingester.networkPolicy.ingressNSMatchLabels`    | Labels to match to allow traffic from other namespaces. Ignored if `ingester.networkPolicy.allowExternal` is true.     | `{}`        |
| `ingester.networkPolicy.ingressNSPodMatchLabels` | Pod labels to match to allow traffic from other namespaces. Ignored if `ingester.networkPolicy.allowExternal` is true. | `{}`        |

### Querier Deployment Parameters

| Name                                                        | Description                                                                                                                                                                                                                       | Value            |
| ----------------------------------------------------------- | --------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | ---------------- |
| `querier.replicaCount`                                      | Number of Querier replicas to deploy                                                                                                                                                                                              | `1`              |
| `querier.extraEnvVars`                                      | Array with extra environment variables to add to Querier nodes                                                                                                                                                                    | `[]`             |
| `querier.extraEnvVarsCM`                                    | Name of existing ConfigMap containing extra env vars for Querier nodes                                                                                                                                                            | `""`             |
| `querier.extraEnvVarsSecret`                                | Name of existing Secret containing extra env vars for Querier nodes                                                                                                                                                               | `""`             |
| `querier.command`                                           | Override default container command (useful when using custom images)                                                                                                                                                              | `[]`             |
| `querier.args`                                              | Override default container args (useful when using custom images)                                                                                                                                                                 | `[]`             |
| `querier.livenessProbe.enabled`                             | Enable livenessProbe on Querier nodes                                                                                                                                                                                             | `true`           |
| `querier.livenessProbe.initialDelaySeconds`                 | Initial delay seconds for livenessProbe                                                                                                                                                                                           | `10`             |
| `querier.livenessProbe.periodSeconds`                       | Period seconds for livenessProbe                                                                                                                                                                                                  | `10`             |
| `querier.livenessProbe.timeoutSeconds`                      | Timeout seconds for livenessProbe                                                                                                                                                                                                 | `1`              |
| `querier.livenessProbe.failureThreshold`                    | Failure threshold for livenessProbe                                                                                                                                                                                               | `3`              |
| `querier.livenessProbe.successThreshold`                    | Success threshold for livenessProbe                                                                                                                                                                                               | `1`              |
| `querier.readinessProbe.enabled`                            | Enable readinessProbe on Querier nodes                                                                                                                                                                                            | `true`           |
| `querier.readinessProbe.initialDelaySeconds`                | Initial delay seconds for readinessProbe                                                                                                                                                                                          | `10`             |
| `querier.readinessProbe.periodSeconds`                      | Period seconds for readinessProbe                                                                                                                                                                                                 | `10`             |
| `querier.readinessProbe.timeoutSeconds`                     | Timeout seconds for readinessProbe                                                                                                                                                                                                | `1`              |
| `querier.readinessProbe.failureThreshold`                   | Failure threshold for readinessProbe                                                                                                                                                                                              | `3`              |
| `querier.readinessProbe.successThreshold`                   | Success threshold for readinessProbe                                                                                                                                                                                              | `1`              |
| `querier.startupProbe.enabled`                              | Enable startupProbe on Querier containers                                                                                                                                                                                         | `false`          |
| `querier.startupProbe.initialDelaySeconds`                  | Initial delay seconds for startupProbe                                                                                                                                                                                            | `30`             |
| `querier.startupProbe.periodSeconds`                        | Period seconds for startupProbe                                                                                                                                                                                                   | `10`             |
| `querier.startupProbe.timeoutSeconds`                       | Timeout seconds for startupProbe                                                                                                                                                                                                  | `1`              |
| `querier.startupProbe.failureThreshold`                     | Failure threshold for startupProbe                                                                                                                                                                                                | `15`             |
| `querier.startupProbe.successThreshold`                     | Success threshold for startupProbe                                                                                                                                                                                                | `1`              |
| `querier.customLivenessProbe`                               | Custom livenessProbe that overrides the default one                                                                                                                                                                               | `{}`             |
| `querier.customReadinessProbe`                              | Custom readinessProbe that overrides the default one                                                                                                                                                                              | `{}`             |
| `querier.customStartupProbe`                                | Custom startupProbe that overrides the default one                                                                                                                                                                                | `{}`             |
| `querier.resourcesPreset`                                   | Set container resources according to one common preset (allowed values: none, nano, micro, small, medium, large, xlarge, 2xlarge). This is ignored if querier.resources is set (querier.resources is recommended for production). | `nano`           |
| `querier.resources`                                         | Set container requests and limits for different resources like CPU or memory (essential for production workloads)                                                                                                                 | `{}`             |
| `querier.podSecurityContext.enabled`                        | Enabled Querier pods' Security Context                                                                                                                                                                                            | `true`           |
| `querier.podSecurityContext.fsGroupChangePolicy`            | Set filesystem group change policy                                                                                                                                                                                                | `Always`         |
| `querier.podSecurityContext.sysctls`                        | Set kernel settings using the sysctl interface                                                                                                                                                                                    | `[]`             |
| `querier.podSecurityContext.supplementalGroups`             | Set filesystem extra groups                                                                                                                                                                                                       | `[]`             |
| `querier.podSecurityContext.fsGroup`                        | Set Querier pod's Security Context fsGroup                                                                                                                                                                                        | `1001`           |
| `querier.containerSecurityContext.enabled`                  | Enabled containers' Security Context                                                                                                                                                                                              | `true`           |
| `querier.containerSecurityContext.seLinuxOptions`           | Set SELinux options in container                                                                                                                                                                                                  | `{}`             |
| `querier.containerSecurityContext.runAsUser`                | Set containers' Security Context runAsUser                                                                                                                                                                                        | `1001`           |
| `querier.containerSecurityContext.runAsGroup`               | Set containers' Security Context runAsGroup                                                                                                                                                                                       | `1001`           |
| `querier.containerSecurityContext.runAsNonRoot`             | Set container's Security Context runAsNonRoot                                                                                                                                                                                     | `true`           |
| `querier.containerSecurityContext.privileged`               | Set container's Security Context privileged                                                                                                                                                                                       | `false`          |
| `querier.containerSecurityContext.readOnlyRootFilesystem`   | Set container's Security Context readOnlyRootFilesystem                                                                                                                                                                           | `true`           |
| `querier.containerSecurityContext.allowPrivilegeEscalation` | Set container's Security Context allowPrivilegeEscalation                                                                                                                                                                         | `false`          |
| `querier.containerSecurityContext.capabilities.drop`        | List of capabilities to be dropped                                                                                                                                                                                                | `["ALL"]`        |
| `querier.containerSecurityContext.seccompProfile.type`      | Set container's Security Context seccomp profile                                                                                                                                                                                  | `RuntimeDefault` |
| `querier.lifecycleHooks`                                    | for the Querier container(s) to automate configuration before or after startup                                                                                                                                                    | `{}`             |
| `querier.automountServiceAccountToken`                      | Mount Service Account token in pod                                                                                                                                                                                                | `false`          |
| `querier.hostAliases`                                       | querier pods host aliases                                                                                                                                                                                                         | `[]`             |
| `querier.podLabels`                                         | Extra labels for querier pods                                                                                                                                                                                                     | `{}`             |
| `querier.podAnnotations`                                    | Annotations for querier pods                                                                                                                                                                                                      | `{}`             |
| `querier.podAffinityPreset`                                 | Pod affinity preset. Ignored if `querier.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                       | `""`             |
| `querier.podAntiAffinityPreset`                             | Pod anti-affinity preset. Ignored if `querier.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                  | `soft`           |
| `querier.nodeAffinityPreset.type`                           | Node affinity preset type. Ignored if `querier.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                 | `""`             |
| `querier.nodeAffinityPreset.key`                            | Node label key to match. Ignored if `querier.affinity` is set                                                                                                                                                                     | `""`             |
| `querier.nodeAffinityPreset.values`                         | Node label values to match. Ignored if `querier.affinity` is set                                                                                                                                                                  | `[]`             |
| `querier.affinity`                                          | Affinity for Querier pods assignment                                                                                                                                                                                              | `{}`             |
| `querier.nodeSelector`                                      | Node labels for Querier pods assignment                                                                                                                                                                                           | `{}`             |
| `querier.tolerations`                                       | Tolerations for Querier pods assignment                                                                                                                                                                                           | `[]`             |
| `querier.topologySpreadConstraints`                         | Topology Spread Constraints for pod assignment spread across your cluster among failure-domains                                                                                                                                   | `[]`             |
| `querier.priorityClassName`                                 | Querier pods' priorityClassName                                                                                                                                                                                                   | `""`             |
| `querier.schedulerName`                                     | Kubernetes pod scheduler registry                                                                                                                                                                                                 | `""`             |
| `querier.updateStrategy.type`                               | Querier statefulset strategy type                                                                                                                                                                                                 | `RollingUpdate`  |
| `querier.updateStrategy.rollingUpdate`                      | Querier statefulset rolling update configuration parameters                                                                                                                                                                       | `{}`             |
| `querier.extraVolumes`                                      | Optionally specify extra list of additional volumes for the Querier pod(s)                                                                                                                                                        | `[]`             |
| `querier.extraVolumeMounts`                                 | Optionally specify extra list of additional volumeMounts for the querier container(s)                                                                                                                                             | `[]`             |
| `querier.sidecars`                                          | Add additional sidecar containers to the Querier pod(s)                                                                                                                                                                           | `[]`             |
| `querier.initContainers`                                    | Add additional init containers to the Querier pod(s)                                                                                                                                                                              | `[]`             |
| `querier.pdb.create`                                        | Enable/disable a Pod Disruption Budget creation                                                                                                                                                                                   | `true`           |
| `querier.pdb.minAvailable`                                  | Minimum number/percentage of pods that should remain scheduled                                                                                                                                                                    | `""`             |
| `querier.pdb.maxUnavailable`                                | Maximum number/percentage of pods that may be made unavailable. Defaults to `1` if both `querier.pdb.minAvailable` and `querier.pdb.maxUnavailable` are empty.                                                                    | `""`             |
| `querier.enableServiceLinks`                                | Whether information about services should be injected into pod's environment variable                                                                                                                                             | `true`           |

### Querier Traffic Exposure Parameters

| Name                                            | Description                                                                                                           | Value       |
| ----------------------------------------------- | --------------------------------------------------------------------------------------------------------------------- | ----------- |
| `querier.service.type`                          | Querier service type                                                                                                  | `ClusterIP` |
| `querier.service.ports.http`                    | Querier HTTP service port                                                                                             | `3200`      |
| `querier.service.ports.grpc`                    | Querier GRPC service port                                                                                             | `9095`      |
| `querier.service.nodePorts.http`                | Node port for HTTP                                                                                                    | `""`        |
| `querier.service.nodePorts.grpc`                | Node port for GRPC                                                                                                    | `""`        |
| `querier.service.sessionAffinity`               | Control where client requests go, to the same pod or round-robin                                                      | `None`      |
| `querier.service.sessionAffinityConfig`         | Additional settings for the sessionAffinity                                                                           | `{}`        |
| `querier.service.clusterIP`                     | Querier service Cluster IP                                                                                            | `""`        |
| `querier.service.loadBalancerIP`                | Querier service Load Balancer IP                                                                                      | `""`        |
| `querier.service.loadBalancerSourceRanges`      | Querier service Load Balancer sources                                                                                 | `[]`        |
| `querier.service.externalTrafficPolicy`         | Querier service external traffic policy                                                                               | `Cluster`   |
| `querier.service.annotations`                   | Additional custom annotations for Querier service                                                                     | `{}`        |
| `querier.service.extraPorts`                    | Extra ports to expose in the Querier service                                                                          | `[]`        |
| `querier.networkPolicy.enabled`                 | Specifies whether a NetworkPolicy should be created                                                                   | `true`      |
| `querier.networkPolicy.allowExternal`           | Don't require server label for connections                                                                            | `true`      |
| `querier.networkPolicy.allowExternalEgress`     | Allow the pod to access any range of port and all destinations.                                                       | `true`      |
| `querier.networkPolicy.addExternalClientAccess` | Allow access from pods with client label set to "true". Ignored if `querier.networkPolicy.allowExternal` is true.     | `true`      |
| `querier.networkPolicy.extraIngress`            | Add extra ingress rules to the NetworkPolicy                                                                          | `[]`        |
| `querier.networkPolicy.extraEgress`             | Add extra ingress rules to the NetworkPolicy                                                                          | `[]`        |
| `querier.networkPolicy.ingressPodMatchLabels`   | Labels to match to allow traffic from other pods. Ignored if `querier.networkPolicy.allowExternal` is true.           | `{}`        |
| `querier.networkPolicy.ingressNSMatchLabels`    | Labels to match to allow traffic from other namespaces. Ignored if `querier.networkPolicy.allowExternal` is true.     | `{}`        |
| `querier.networkPolicy.ingressNSPodMatchLabels` | Pod labels to match to allow traffic from other namespaces. Ignored if `querier.networkPolicy.allowExternal` is true. | `{}`        |

### Query Frontend Deployment Parameters

| Name                                                                    | Description                                                                                                                                                                                                                                               | Value                                 |
| ----------------------------------------------------------------------- | --------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------- |
| `queryFrontend.extraEnvVars`                                            | Array with extra environment variables to add to queryFrontend nodes                                                                                                                                                                                      | `[]`                                  |
| `queryFrontend.extraEnvVarsCM`                                          | Name of existing ConfigMap containing extra env vars for queryFrontend nodes                                                                                                                                                                              | `""`                                  |
| `queryFrontend.extraEnvVarsSecret`                                      | Name of existing Secret containing extra env vars for queryFrontend nodes                                                                                                                                                                                 | `""`                                  |
| `queryFrontend.command`                                                 | Override default container command (useful when using custom images)                                                                                                                                                                                      | `[]`                                  |
| `queryFrontend.args`                                                    | Override default container args (useful when using custom images)                                                                                                                                                                                         | `[]`                                  |
| `queryFrontend.replicaCount`                                            | Number of queryFrontend replicas to deploy                                                                                                                                                                                                                | `1`                                   |
| `queryFrontend.livenessProbe.enabled`                                   | Enable livenessProbe on queryFrontend nodes                                                                                                                                                                                                               | `true`                                |
| `queryFrontend.livenessProbe.initialDelaySeconds`                       | Initial delay seconds for livenessProbe                                                                                                                                                                                                                   | `10`                                  |
| `queryFrontend.livenessProbe.periodSeconds`                             | Period seconds for livenessProbe                                                                                                                                                                                                                          | `10`                                  |
| `queryFrontend.livenessProbe.timeoutSeconds`                            | Timeout seconds for livenessProbe                                                                                                                                                                                                                         | `1`                                   |
| `queryFrontend.livenessProbe.failureThreshold`                          | Failure threshold for livenessProbe                                                                                                                                                                                                                       | `3`                                   |
| `queryFrontend.livenessProbe.successThreshold`                          | Success threshold for livenessProbe                                                                                                                                                                                                                       | `1`                                   |
| `queryFrontend.readinessProbe.enabled`                                  | Enable readinessProbe on queryFrontend nodes                                                                                                                                                                                                              | `true`                                |
| `queryFrontend.readinessProbe.initialDelaySeconds`                      | Initial delay seconds for readinessProbe                                                                                                                                                                                                                  | `10`                                  |
| `queryFrontend.readinessProbe.periodSeconds`                            | Period seconds for readinessProbe                                                                                                                                                                                                                         | `10`                                  |
| `queryFrontend.readinessProbe.timeoutSeconds`                           | Timeout seconds for readinessProbe                                                                                                                                                                                                                        | `1`                                   |
| `queryFrontend.readinessProbe.failureThreshold`                         | Failure threshold for readinessProbe                                                                                                                                                                                                                      | `3`                                   |
| `queryFrontend.readinessProbe.successThreshold`                         | Success threshold for readinessProbe                                                                                                                                                                                                                      | `1`                                   |
| `queryFrontend.startupProbe.enabled`                                    | Enable startupProbe on queryFrontend containers                                                                                                                                                                                                           | `false`                               |
| `queryFrontend.startupProbe.initialDelaySeconds`                        | Initial delay seconds for startupProbe                                                                                                                                                                                                                    | `30`                                  |
| `queryFrontend.startupProbe.periodSeconds`                              | Period seconds for startupProbe                                                                                                                                                                                                                           | `10`                                  |
| `queryFrontend.startupProbe.timeoutSeconds`                             | Timeout seconds for startupProbe                                                                                                                                                                                                                          | `1`                                   |
| `queryFrontend.startupProbe.failureThreshold`                           | Failure threshold for startupProbe                                                                                                                                                                                                                        | `15`                                  |
| `queryFrontend.startupProbe.successThreshold`                           | Success threshold for startupProbe                                                                                                                                                                                                                        | `1`                                   |
| `queryFrontend.customLivenessProbe`                                     | Custom livenessProbe that overrides the default one                                                                                                                                                                                                       | `{}`                                  |
| `queryFrontend.customReadinessProbe`                                    | Custom readinessProbe that overrides the default one                                                                                                                                                                                                      | `{}`                                  |
| `queryFrontend.customStartupProbe`                                      | Custom startupProbe that overrides the default one                                                                                                                                                                                                        | `{}`                                  |
| `queryFrontend.resourcesPreset`                                         | Set container resources according to one common preset (allowed values: none, nano, micro, small, medium, large, xlarge, 2xlarge). This is ignored if queryFrontend.resources is set (queryFrontend.resources is recommended for production).             | `nano`                                |
| `queryFrontend.resources`                                               | Set container requests and limits for different resources like CPU or memory (essential for production workloads)                                                                                                                                         | `{}`                                  |
| `queryFrontend.podSecurityContext.enabled`                              | Enabled queryFrontend pods' Security Context                                                                                                                                                                                                              | `true`                                |
| `queryFrontend.podSecurityContext.fsGroupChangePolicy`                  | Set filesystem group change policy                                                                                                                                                                                                                        | `Always`                              |
| `queryFrontend.podSecurityContext.sysctls`                              | Set kernel settings using the sysctl interface                                                                                                                                                                                                            | `[]`                                  |
| `queryFrontend.podSecurityContext.supplementalGroups`                   | Set filesystem extra groups                                                                                                                                                                                                                               | `[]`                                  |
| `queryFrontend.podSecurityContext.fsGroup`                              | Set queryFrontend pod's Security Context fsGroup                                                                                                                                                                                                          | `1001`                                |
| `queryFrontend.containerSecurityContext.enabled`                        | Enabled containers' Security Context                                                                                                                                                                                                                      | `true`                                |
| `queryFrontend.containerSecurityContext.seLinuxOptions`                 | Set SELinux options in container                                                                                                                                                                                                                          | `{}`                                  |
| `queryFrontend.containerSecurityContext.runAsUser`                      | Set containers' Security Context runAsUser                                                                                                                                                                                                                | `1001`                                |
| `queryFrontend.containerSecurityContext.runAsGroup`                     | Set containers' Security Context runAsGroup                                                                                                                                                                                                               | `1001`                                |
| `queryFrontend.containerSecurityContext.runAsNonRoot`                   | Set container's Security Context runAsNonRoot                                                                                                                                                                                                             | `true`                                |
| `queryFrontend.containerSecurityContext.privileged`                     | Set container's Security Context privileged                                                                                                                                                                                                               | `false`                               |
| `queryFrontend.containerSecurityContext.readOnlyRootFilesystem`         | Set container's Security Context readOnlyRootFilesystem                                                                                                                                                                                                   | `true`                                |
| `queryFrontend.containerSecurityContext.allowPrivilegeEscalation`       | Set container's Security Context allowPrivilegeEscalation                                                                                                                                                                                                 | `false`                               |
| `queryFrontend.containerSecurityContext.capabilities.drop`              | List of capabilities to be dropped                                                                                                                                                                                                                        | `["ALL"]`                             |
| `queryFrontend.containerSecurityContext.seccompProfile.type`            | Set container's Security Context seccomp profile                                                                                                                                                                                                          | `RuntimeDefault`                      |
| `queryFrontend.lifecycleHooks`                                          | for the queryFrontend container(s) to automate configuration before or after startup                                                                                                                                                                      | `{}`                                  |
| `queryFrontend.automountServiceAccountToken`                            | Mount Service Account token in pod                                                                                                                                                                                                                        | `false`                               |
| `queryFrontend.hostAliases`                                             | queryFrontend pods host aliases                                                                                                                                                                                                                           | `[]`                                  |
| `queryFrontend.podLabels`                                               | Extra labels for queryFrontend pods                                                                                                                                                                                                                       | `{}`                                  |
| `queryFrontend.podAnnotations`                                          | Annotations for queryFrontend pods                                                                                                                                                                                                                        | `{}`                                  |
| `queryFrontend.podAffinityPreset`                                       | Pod affinity preset. Ignored if `queryFrontend.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                                         | `""`                                  |
| `queryFrontend.podAntiAffinityPreset`                                   | Pod anti-affinity preset. Ignored if `queryFrontend.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                                    | `soft`                                |
| `queryFrontend.nodeAffinityPreset.type`                                 | Node affinity preset type. Ignored if `queryFrontend.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                                   | `""`                                  |
| `queryFrontend.nodeAffinityPreset.key`                                  | Node label key to match. Ignored if `queryFrontend.affinity` is set                                                                                                                                                                                       | `""`                                  |
| `queryFrontend.nodeAffinityPreset.values`                               | Node label values to match. Ignored if `queryFrontend.affinity` is set                                                                                                                                                                                    | `[]`                                  |
| `queryFrontend.affinity`                                                | Affinity for queryFrontend pods assignment                                                                                                                                                                                                                | `{}`                                  |
| `queryFrontend.nodeSelector`                                            | Node labels for queryFrontend pods assignment                                                                                                                                                                                                             | `{}`                                  |
| `queryFrontend.tolerations`                                             | Tolerations for queryFrontend pods assignment                                                                                                                                                                                                             | `[]`                                  |
| `queryFrontend.topologySpreadConstraints`                               | Topology Spread Constraints for pod assignment spread across your cluster among failure-domains                                                                                                                                                           | `[]`                                  |
| `queryFrontend.priorityClassName`                                       | queryFrontend pods' priorityClassName                                                                                                                                                                                                                     | `""`                                  |
| `queryFrontend.schedulerName`                                           | Kubernetes pod scheduler registry                                                                                                                                                                                                                         | `""`                                  |
| `queryFrontend.updateStrategy.type`                                     | queryFrontend statefulset strategy type                                                                                                                                                                                                                   | `RollingUpdate`                       |
| `queryFrontend.updateStrategy.rollingUpdate`                            | queryFrontend statefulset rolling update configuration parameters                                                                                                                                                                                         | `{}`                                  |
| `queryFrontend.extraVolumes`                                            | Optionally specify extra list of additional volumes for the queryFrontend pod(s)                                                                                                                                                                          | `[]`                                  |
| `queryFrontend.extraVolumeMounts`                                       | Optionally specify extra list of additional volumeMounts for the queryFrontend container(s)                                                                                                                                                               | `[]`                                  |
| `queryFrontend.sidecars`                                                | Add additional sidecar containers to the queryFrontend pod(s)                                                                                                                                                                                             | `[]`                                  |
| `queryFrontend.initContainers`                                          | Add additional init containers to the queryFrontend pod(s)                                                                                                                                                                                                | `[]`                                  |
| `queryFrontend.pdb.create`                                              | Enable/disable a Pod Disruption Budget creation                                                                                                                                                                                                           | `true`                                |
| `queryFrontend.pdb.minAvailable`                                        | Minimum number/percentage of pods that should remain scheduled                                                                                                                                                                                            | `""`                                  |
| `queryFrontend.pdb.maxUnavailable`                                      | Maximum number/percentage of pods that may be made unavailable. Defaults to `1` if both `queryFrontend.pdb.minAvailable` and `queryFrontend.pdb.maxUnavailable` are empty.                                                                                | `""`                                  |
| `queryFrontend.enableServiceLinks`                                      | Whether information about services should be injected into pod's environment variable                                                                                                                                                                     | `true`                                |
| `queryFrontend.query.enabled`                                           | Whether to enable the query container for legacy Grafana compatibility with jaeger-ui.  Only required for grafana version <7.5                                                                                                                            | `false`                               |
| `queryFrontend.query.image.registry`                                    | Grafana Tempo Query image registry                                                                                                                                                                                                                        | `REGISTRY_NAME`                       |
| `queryFrontend.query.image.repository`                                  | Grafana Tempo Query image repository                                                                                                                                                                                                                      | `REPOSITORY_NAME/grafana-tempo-query` |
| `queryFrontend.query.image.digest`                                      | Grafana Tempo Query image digest in the way sha256:aa.... Please note this parameter, if set, will override the tag                                                                                                                                       | `""`                                  |
| `queryFrontend.query.image.pullPolicy`                                  | Grafana Tempo Query image pull policy                                                                                                                                                                                                                     | `IfNotPresent`                        |
| `queryFrontend.query.image.pullSecrets`                                 | Grafana Tempo Query image pull secrets                                                                                                                                                                                                                    | `[]`                                  |
| `queryFrontend.query.configuration`                                     | Query sidecar configuration                                                                                                                                                                                                                               | `""`                                  |
| `queryFrontend.query.containerPorts.jaegerMetrics`                      | queryFrontend query sidecar Jaeger metrics container port                                                                                                                                                                                                 | `16687`                               |
| `queryFrontend.query.containerPorts.jaegerUI`                           | queryFrontend query sidecar Jaeger UI container port                                                                                                                                                                                                      | `16686`                               |
| `queryFrontend.query.containerPorts.jaegerGRPC`                         | queryFrontend query sidecar Jaeger UI container port                                                                                                                                                                                                      | `16685`                               |
| `queryFrontend.query.existingConfigmap`                                 | Name of a configmap with the query configuration                                                                                                                                                                                                          | `""`                                  |
| `queryFrontend.query.extraEnvVars`                                      | Array with extra environment variables to add to queryFrontend nodes                                                                                                                                                                                      | `[]`                                  |
| `queryFrontend.query.extraEnvVarsCM`                                    | Name of existing ConfigMap containing extra env vars for queryFrontend nodes                                                                                                                                                                              | `""`                                  |
| `queryFrontend.query.extraEnvVarsSecret`                                | Name of existing Secret containing extra env vars for queryFrontend nodes                                                                                                                                                                                 | `""`                                  |
| `queryFrontend.query.command`                                           | Override default container command (useful when using custom images)                                                                                                                                                                                      | `[]`                                  |
| `queryFrontend.query.args`                                              | Override default container args (useful when using custom images)                                                                                                                                                                                         | `[]`                                  |
| `queryFrontend.query.livenessProbe.enabled`                             | Enable livenessProbe on Query sidecar nodes                                                                                                                                                                                                               | `true`                                |
| `queryFrontend.query.livenessProbe.initialDelaySeconds`                 | Initial delay seconds for livenessProbe                                                                                                                                                                                                                   | `10`                                  |
| `queryFrontend.query.livenessProbe.periodSeconds`                       | Period seconds for livenessProbe                                                                                                                                                                                                                          | `10`                                  |
| `queryFrontend.query.livenessProbe.timeoutSeconds`                      | Timeout seconds for livenessProbe                                                                                                                                                                                                                         | `1`                                   |
| `queryFrontend.query.livenessProbe.failureThreshold`                    | Failure threshold for livenessProbe                                                                                                                                                                                                                       | `3`                                   |
| `queryFrontend.query.livenessProbe.successThreshold`                    | Success threshold for livenessProbe                                                                                                                                                                                                                       | `1`                                   |
| `queryFrontend.query.readinessProbe.enabled`                            | Enable readinessProbe on Query sidecar nodes                                                                                                                                                                                                              | `true`                                |
| `queryFrontend.query.readinessProbe.initialDelaySeconds`                | Initial delay seconds for readinessProbe                                                                                                                                                                                                                  | `10`                                  |
| `queryFrontend.query.readinessProbe.periodSeconds`                      | Period seconds for readinessProbe                                                                                                                                                                                                                         | `10`                                  |
| `queryFrontend.query.readinessProbe.timeoutSeconds`                     | Timeout seconds for readinessProbe                                                                                                                                                                                                                        | `1`                                   |
| `queryFrontend.query.readinessProbe.failureThreshold`                   | Failure threshold for readinessProbe                                                                                                                                                                                                                      | `3`                                   |
| `queryFrontend.query.readinessProbe.successThreshold`                   | Success threshold for readinessProbe                                                                                                                                                                                                                      | `1`                                   |
| `queryFrontend.query.startupProbe.enabled`                              | Enable startupProbe on Query sidecar containers                                                                                                                                                                                                           | `false`                               |
| `queryFrontend.query.startupProbe.initialDelaySeconds`                  | Initial delay seconds for startupProbe                                                                                                                                                                                                                    | `30`                                  |
| `queryFrontend.query.startupProbe.periodSeconds`                        | Period seconds for startupProbe                                                                                                                                                                                                                           | `10`                                  |
| `queryFrontend.query.startupProbe.timeoutSeconds`                       | Timeout seconds for startupProbe                                                                                                                                                                                                                          | `1`                                   |
| `queryFrontend.query.startupProbe.failureThreshold`                     | Failure threshold for startupProbe                                                                                                                                                                                                                        | `15`                                  |
| `queryFrontend.query.startupProbe.successThreshold`                     | Success threshold for startupProbe                                                                                                                                                                                                                        | `1`                                   |
| `queryFrontend.query.customLivenessProbe`                               | Custom livenessProbe that overrides the default one                                                                                                                                                                                                       | `{}`                                  |
| `queryFrontend.query.customReadinessProbe`                              | Custom readinessProbe that overrides the default one                                                                                                                                                                                                      | `{}`                                  |
| `queryFrontend.query.customStartupProbe`                                | Custom startupProbe that overrides the default one                                                                                                                                                                                                        | `{}`                                  |
| `queryFrontend.query.lifecycleHooks`                                    | for the query sidecar container(s) to automate configuration before or after startup                                                                                                                                                                      | `{}`                                  |
| `queryFrontend.query.containerSecurityContext.enabled`                  | Enabled containers' Security Context                                                                                                                                                                                                                      | `true`                                |
| `queryFrontend.query.containerSecurityContext.seLinuxOptions`           | Set SELinux options in container                                                                                                                                                                                                                          | `{}`                                  |
| `queryFrontend.query.containerSecurityContext.runAsUser`                | Set containers' Security Context runAsUser                                                                                                                                                                                                                | `1001`                                |
| `queryFrontend.query.containerSecurityContext.runAsGroup`               | Set containers' Security Context runAsGroup                                                                                                                                                                                                               | `1001`                                |
| `queryFrontend.query.containerSecurityContext.runAsNonRoot`             | Set container's Security Context runAsNonRoot                                                                                                                                                                                                             | `true`                                |
| `queryFrontend.query.containerSecurityContext.privileged`               | Set container's Security Context privileged                                                                                                                                                                                                               | `false`                               |
| `queryFrontend.query.containerSecurityContext.readOnlyRootFilesystem`   | Set container's Security Context readOnlyRootFilesystem                                                                                                                                                                                                   | `true`                                |
| `queryFrontend.query.containerSecurityContext.allowPrivilegeEscalation` | Set container's Security Context allowPrivilegeEscalation                                                                                                                                                                                                 | `false`                               |
| `queryFrontend.query.containerSecurityContext.capabilities.drop`        | List of capabilities to be dropped                                                                                                                                                                                                                        | `["ALL"]`                             |
| `queryFrontend.query.containerSecurityContext.seccompProfile.type`      | Set container's Security Context seccomp profile                                                                                                                                                                                                          | `RuntimeDefault`                      |
| `queryFrontend.query.resourcesPreset`                                   | Set container resources according to one common preset (allowed values: none, nano, micro, small, medium, large, xlarge, 2xlarge). This is ignored if queryFrontend.query.resources is set (queryFrontend.query.resources is recommended for production). | `nano`                                |
| `queryFrontend.query.resources`                                         | Set container requests and limits for different resources like CPU or memory (essential for production workloads)                                                                                                                                         | `{}`                                  |
| `queryFrontend.query.extraVolumeMounts`                                 | Optionally specify extra list of additional volumeMounts for the queryFrontend container(s)                                                                                                                                                               | `[]`                                  |

### Query Frontend Traffic Exposure Parameters

| Name                                                  | Description                                                                                                                 | Value       |
| ----------------------------------------------------- | --------------------------------------------------------------------------------------------------------------------------- | ----------- |
| `queryFrontend.service.type`                          | queryFrontend service type                                                                                                  | `ClusterIP` |
| `queryFrontend.service.ports.http`                    | queryFrontend HTTP service port                                                                                             | `3200`      |
| `queryFrontend.service.ports.grpc`                    | queryFrontend GRPC service port                                                                                             | `9095`      |
| `queryFrontend.service.nodePorts.http`                | Node port for HTTP                                                                                                          | `""`        |
| `queryFrontend.service.nodePorts.grpc`                | Node port for GRPC                                                                                                          | `""`        |
| `queryFrontend.service.sessionAffinity`               | Control where client requests go, to the same pod or round-robin                                                            | `None`      |
| `queryFrontend.service.sessionAffinityConfig`         | Additional settings for the sessionAffinity                                                                                 | `{}`        |
| `queryFrontend.service.clusterIP`                     | queryFrontend service Cluster IP                                                                                            | `""`        |
| `queryFrontend.service.loadBalancerIP`                | queryFrontend service Load Balancer IP                                                                                      | `""`        |
| `queryFrontend.service.loadBalancerSourceRanges`      | queryFrontend service Load Balancer sources                                                                                 | `[]`        |
| `queryFrontend.service.externalTrafficPolicy`         | queryFrontend service external traffic policy                                                                               | `Cluster`   |
| `queryFrontend.service.annotations`                   | Additional custom annotations for queryFrontend service                                                                     | `{}`        |
| `queryFrontend.service.extraPorts`                    | Extra ports to expose in the queryFrontend service                                                                          | `[]`        |
| `queryFrontend.service.headless.annotations`          | Annotations for the headless service.                                                                                       | `{}`        |
| `queryFrontend.networkPolicy.enabled`                 | Specifies whether a NetworkPolicy should be created                                                                         | `true`      |
| `queryFrontend.networkPolicy.allowExternal`           | Don't require server label for connections                                                                                  | `true`      |
| `queryFrontend.networkPolicy.allowExternalEgress`     | Allow the pod to access any range of port and all destinations.                                                             | `true`      |
| `queryFrontend.networkPolicy.addExternalClientAccess` | Allow access from pods with client label set to "true". Ignored if `queryFrontend.networkPolicy.allowExternal` is true.     | `true`      |
| `queryFrontend.networkPolicy.extraIngress`            | Add extra ingress rules to the NetworkPolicy                                                                                | `[]`        |
| `queryFrontend.networkPolicy.extraEgress`             | Add extra ingress rules to the NetworkPolicy                                                                                | `[]`        |
| `queryFrontend.networkPolicy.ingressPodMatchLabels`   | Labels to match to allow traffic from other pods. Ignored if `queryFrontend.networkPolicy.allowExternal` is true.           | `{}`        |
| `queryFrontend.networkPolicy.ingressNSMatchLabels`    | Labels to match to allow traffic from other namespaces. Ignored if `queryFrontend.networkPolicy.allowExternal` is true.     | `{}`        |
| `queryFrontend.networkPolicy.ingressNSPodMatchLabels` | Pod labels to match to allow traffic from other namespaces. Ignored if `queryFrontend.networkPolicy.allowExternal` is true. | `{}`        |

### Vulture Deployment Parameters

| Name                                                        | Description                                                                                                                                                                                                                       | Value                                   |
| ----------------------------------------------------------- | --------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | --------------------------------------- |
| `vulture.enabled`                                           | Enable vulture deployment                                                                                                                                                                                                         | `true`                                  |
| `vulture.image.registry`                                    | Grafana Vulture image registry                                                                                                                                                                                                    | `REGISTRY_NAME`                         |
| `vulture.image.repository`                                  | Grafana Vulture image repository                                                                                                                                                                                                  | `REPOSITORY_NAME/grafana-tempo-vulture` |
| `vulture.image.digest`                                      | Grafana Vulture image digest in the way sha256:aa.... Please note this parameter, if set, will override the tag                                                                                                                   | `""`                                    |
| `vulture.image.pullPolicy`                                  | Grafana Vulture image pull policy                                                                                                                                                                                                 | `IfNotPresent`                          |
| `vulture.image.pullSecrets`                                 | Grafana Vulture image pull secrets                                                                                                                                                                                                | `[]`                                    |
| `vulture.extraEnvVars`                                      | Array with extra environment variables to add to vulture nodes                                                                                                                                                                    | `[]`                                    |
| `vulture.extraEnvVarsCM`                                    | Name of existing ConfigMap containing extra env vars for vulture nodes                                                                                                                                                            | `""`                                    |
| `vulture.extraEnvVarsSecret`                                | Name of existing Secret containing extra env vars for vulture nodes                                                                                                                                                               | `""`                                    |
| `vulture.command`                                           | Override default container command (useful when using custom images)                                                                                                                                                              | `[]`                                    |
| `vulture.args`                                              | Override default container args (useful when using custom images)                                                                                                                                                                 | `[]`                                    |
| `vulture.replicaCount`                                      | Number of Vulture replicas to deploy                                                                                                                                                                                              | `1`                                     |
| `vulture.livenessProbe.enabled`                             | Enable livenessProbe on Vulture nodes                                                                                                                                                                                             | `true`                                  |
| `vulture.livenessProbe.initialDelaySeconds`                 | Initial delay seconds for livenessProbe                                                                                                                                                                                           | `10`                                    |
| `vulture.livenessProbe.periodSeconds`                       | Period seconds for livenessProbe                                                                                                                                                                                                  | `10`                                    |
| `vulture.livenessProbe.timeoutSeconds`                      | Timeout seconds for livenessProbe                                                                                                                                                                                                 | `1`                                     |
| `vulture.livenessProbe.failureThreshold`                    | Failure threshold for livenessProbe                                                                                                                                                                                               | `3`                                     |
| `vulture.livenessProbe.successThreshold`                    | Success threshold for livenessProbe                                                                                                                                                                                               | `1`                                     |
| `vulture.readinessProbe.enabled`                            | Enable readinessProbe on Vulture nodes                                                                                                                                                                                            | `true`                                  |
| `vulture.readinessProbe.initialDelaySeconds`                | Initial delay seconds for readinessProbe                                                                                                                                                                                          | `10`                                    |
| `vulture.readinessProbe.periodSeconds`                      | Period seconds for readinessProbe                                                                                                                                                                                                 | `10`                                    |
| `vulture.readinessProbe.timeoutSeconds`                     | Timeout seconds for readinessProbe                                                                                                                                                                                                | `1`                                     |
| `vulture.readinessProbe.failureThreshold`                   | Failure threshold for readinessProbe                                                                                                                                                                                              | `3`                                     |
| `vulture.readinessProbe.successThreshold`                   | Success threshold for readinessProbe                                                                                                                                                                                              | `1`                                     |
| `vulture.startupProbe.enabled`                              | Enable startupProbe on Vulture containers                                                                                                                                                                                         | `false`                                 |
| `vulture.startupProbe.initialDelaySeconds`                  | Initial delay seconds for startupProbe                                                                                                                                                                                            | `30`                                    |
| `vulture.startupProbe.periodSeconds`                        | Period seconds for startupProbe                                                                                                                                                                                                   | `10`                                    |
| `vulture.startupProbe.timeoutSeconds`                       | Timeout seconds for startupProbe                                                                                                                                                                                                  | `1`                                     |
| `vulture.startupProbe.failureThreshold`                     | Failure threshold for startupProbe                                                                                                                                                                                                | `15`                                    |
| `vulture.startupProbe.successThreshold`                     | Success threshold for startupProbe                                                                                                                                                                                                | `1`                                     |
| `vulture.customLivenessProbe`                               | Custom livenessProbe that overrides the default one                                                                                                                                                                               | `{}`                                    |
| `vulture.customReadinessProbe`                              | Custom readinessProbe that overrides the default one                                                                                                                                                                              | `{}`                                    |
| `vulture.customStartupProbe`                                | Custom startupProbe that overrides the default one                                                                                                                                                                                | `{}`                                    |
| `vulture.resourcesPreset`                                   | Set container resources according to one common preset (allowed values: none, nano, micro, small, medium, large, xlarge, 2xlarge). This is ignored if vulture.resources is set (vulture.resources is recommended for production). | `nano`                                  |
| `vulture.resources`                                         | Set container requests and limits for different resources like CPU or memory (essential for production workloads)                                                                                                                 | `{}`                                    |
| `vulture.podSecurityContext.enabled`                        | Enabled Vulture pods' Security Context                                                                                                                                                                                            | `true`                                  |
| `vulture.podSecurityContext.fsGroupChangePolicy`            | Set filesystem group change policy                                                                                                                                                                                                | `Always`                                |
| `vulture.podSecurityContext.sysctls`                        | Set kernel settings using the sysctl interface                                                                                                                                                                                    | `[]`                                    |
| `vulture.podSecurityContext.supplementalGroups`             | Set filesystem extra groups                                                                                                                                                                                                       | `[]`                                    |
| `vulture.podSecurityContext.fsGroup`                        | Set Vulture pod's Security Context fsGroup                                                                                                                                                                                        | `1001`                                  |
| `vulture.containerSecurityContext.enabled`                  | Enabled containers' Security Context                                                                                                                                                                                              | `true`                                  |
| `vulture.containerSecurityContext.seLinuxOptions`           | Set SELinux options in container                                                                                                                                                                                                  | `{}`                                    |
| `vulture.containerSecurityContext.runAsUser`                | Set containers' Security Context runAsUser                                                                                                                                                                                        | `1001`                                  |
| `vulture.containerSecurityContext.runAsGroup`               | Set containers' Security Context runAsGroup                                                                                                                                                                                       | `1001`                                  |
| `vulture.containerSecurityContext.runAsNonRoot`             | Set container's Security Context runAsNonRoot                                                                                                                                                                                     | `true`                                  |
| `vulture.containerSecurityContext.privileged`               | Set container's Security Context privileged                                                                                                                                                                                       | `false`                                 |
| `vulture.containerSecurityContext.readOnlyRootFilesystem`   | Set container's Security Context readOnlyRootFilesystem                                                                                                                                                                           | `true`                                  |
| `vulture.containerSecurityContext.allowPrivilegeEscalation` | Set container's Security Context allowPrivilegeEscalation                                                                                                                                                                         | `false`                                 |
| `vulture.containerSecurityContext.capabilities.drop`        | List of capabilities to be dropped                                                                                                                                                                                                | `["ALL"]`                               |
| `vulture.containerSecurityContext.seccompProfile.type`      | Set container's Security Context seccomp profile                                                                                                                                                                                  | `RuntimeDefault`                        |
| `vulture.lifecycleHooks`                                    | for the vulture container(s) to automate configuration before or after startup                                                                                                                                                    | `{}`                                    |
| `vulture.automountServiceAccountToken`                      | Mount Service Account token in pod                                                                                                                                                                                                | `false`                                 |
| `vulture.hostAliases`                                       | vulture pods host aliases                                                                                                                                                                                                         | `[]`                                    |
| `vulture.podLabels`                                         | Extra labels for vulture pods                                                                                                                                                                                                     | `{}`                                    |
| `vulture.podAnnotations`                                    | Annotations for vulture pods                                                                                                                                                                                                      | `{}`                                    |
| `vulture.podAffinityPreset`                                 | Pod affinity preset. Ignored if `vulture.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                       | `""`                                    |
| `vulture.podAntiAffinityPreset`                             | Pod anti-affinity preset. Ignored if `vulture.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                  | `soft`                                  |
| `vulture.nodeAffinityPreset.type`                           | Node affinity preset type. Ignored if `vulture.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                 | `""`                                    |
| `vulture.nodeAffinityPreset.key`                            | Node label key to match. Ignored if `vulture.affinity` is set                                                                                                                                                                     | `""`                                    |
| `vulture.nodeAffinityPreset.values`                         | Node label values to match. Ignored if `vulture.affinity` is set                                                                                                                                                                  | `[]`                                    |
| `vulture.containerPorts.http`                               | Vulture components HTTP container port                                                                                                                                                                                            | `8080`                                  |
| `vulture.affinity`                                          | Affinity for Vulture pods assignment                                                                                                                                                                                              | `{}`                                    |
| `vulture.nodeSelector`                                      | Node labels for Vulture pods assignment                                                                                                                                                                                           | `{}`                                    |
| `vulture.tolerations`                                       | Tolerations for Vulture pods assignment                                                                                                                                                                                           | `[]`                                    |
| `vulture.topologySpreadConstraints`                         | Topology Spread Constraints for pod assignment spread across your cluster among failure-domains                                                                                                                                   | `[]`                                    |
| `vulture.priorityClassName`                                 | Vulture pods' priorityClassName                                                                                                                                                                                                   | `""`                                    |
| `vulture.schedulerName`                                     | Kubernetes pod scheduler registry                                                                                                                                                                                                 | `""`                                    |
| `vulture.updateStrategy.type`                               | Vulture statefulset strategy type                                                                                                                                                                                                 | `RollingUpdate`                         |
| `vulture.updateStrategy.rollingUpdate`                      | Vulture statefulset rolling update configuration parameters                                                                                                                                                                       | `{}`                                    |
| `vulture.extraVolumes`                                      | Optionally specify extra list of additional volumes for the Vulture pod(s)                                                                                                                                                        | `[]`                                    |
| `vulture.extraVolumeMounts`                                 | Optionally specify extra list of additional volumeMounts for the Vulture container(s)                                                                                                                                             | `[]`                                    |
| `vulture.sidecars`                                          | Add additional sidecar containers to the Vulture pod(s)                                                                                                                                                                           | `[]`                                    |
| `vulture.initContainers`                                    | Add additional init containers to the Vulture pod(s)                                                                                                                                                                              | `[]`                                    |
| `vulture.pdb.create`                                        | Enable/disable a Pod Disruption Budget creation                                                                                                                                                                                   | `true`                                  |
| `vulture.pdb.minAvailable`                                  | Minimum number/percentage of pods that should remain scheduled                                                                                                                                                                    | `""`                                    |
| `vulture.pdb.maxUnavailable`                                | Maximum number/percentage of pods that may be made unavailable. Defaults to `1` if both `vulture.pdb.minAvailable` and `vulture.pdb.maxUnavailable` are empty.                                                                    | `""`                                    |
| `vulture.enableServiceLinks`                                | Whether information about services should be injected into pod's environment variable                                                                                                                                             | `true`                                  |

### Vulture Traffic Exposure Parameters

| Name                                            | Description                                                                                                           | Value       |
| ----------------------------------------------- | --------------------------------------------------------------------------------------------------------------------- | ----------- |
| `vulture.service.type`                          | Vulture service type                                                                                                  | `ClusterIP` |
| `vulture.service.ports.http`                    | Vulture HTTP service port                                                                                             | `3200`      |
| `vulture.service.nodePorts.http`                | Node port for HTTP                                                                                                    | `""`        |
| `vulture.service.sessionAffinity`               | Control where client requests go, to the same pod or round-robin                                                      | `None`      |
| `vulture.service.sessionAffinityConfig`         | Additional settings for the sessionAffinity                                                                           | `{}`        |
| `vulture.service.clusterIP`                     | Vulture service Cluster IP                                                                                            | `""`        |
| `vulture.service.loadBalancerIP`                | Vulture service Load Balancer IP                                                                                      | `""`        |
| `vulture.service.loadBalancerSourceRanges`      | Vulture service Load Balancer sources                                                                                 | `[]`        |
| `vulture.service.externalTrafficPolicy`         | Vulture service external traffic policy                                                                               | `Cluster`   |
| `vulture.service.annotations`                   | Additional custom annotations for Vulture service                                                                     | `{}`        |
| `vulture.service.extraPorts`                    | Extra ports to expose in the Vulture service                                                                          | `[]`        |
| `vulture.networkPolicy.enabled`                 | Specifies whether a NetworkPolicy should be created                                                                   | `true`      |
| `vulture.networkPolicy.allowExternal`           | Don't require server label for connections                                                                            | `true`      |
| `vulture.networkPolicy.allowExternalEgress`     | Allow the pod to access any range of port and all destinations.                                                       | `true`      |
| `vulture.networkPolicy.addExternalClientAccess` | Allow access from pods with client label set to "true". Ignored if `vulture.networkPolicy.allowExternal` is true.     | `true`      |
| `vulture.networkPolicy.extraIngress`            | Add extra ingress rules to the NetworkPolicy                                                                          | `[]`        |
| `vulture.networkPolicy.extraEgress`             | Add extra ingress rules to the NetworkPolicy                                                                          | `[]`        |
| `vulture.networkPolicy.ingressPodMatchLabels`   | Labels to match to allow traffic from other pods. Ignored if `vulture.networkPolicy.allowExternal` is true.           | `{}`        |
| `vulture.networkPolicy.ingressNSMatchLabels`    | Labels to match to allow traffic from other namespaces. Ignored if `vulture.networkPolicy.allowExternal` is true.     | `{}`        |
| `vulture.networkPolicy.ingressNSPodMatchLabels` | Pod labels to match to allow traffic from other namespaces. Ignored if `vulture.networkPolicy.allowExternal` is true. | `{}`        |

### Init Container Parameters

| Name                                                        | Description                                                                                                                                                                                                                                           | Value                      |
| ----------------------------------------------------------- | ----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | -------------------------- |
| `volumePermissions.enabled`                                 | Enable init container that changes the owner/group of the PV mount point to `runAsUser:fsGroup`                                                                                                                                                       | `false`                    |
| `volumePermissions.image.registry`                          | OS Shell + Utility image registry                                                                                                                                                                                                                     | `REGISTRY_NAME`            |
| `volumePermissions.image.repository`                        | OS Shell + Utility image repository                                                                                                                                                                                                                   | `REPOSITORY_NAME/os-shell` |
| `volumePermissions.image.digest`                            | OS Shell + Utility image digest in the way sha256:aa.... Please note this parameter, if set, will override the tag                                                                                                                                    | `""`                       |
| `volumePermissions.image.pullPolicy`                        | OS Shell + Utility image pull policy                                                                                                                                                                                                                  | `IfNotPresent`             |
| `volumePermissions.image.pullSecrets`                       | OS Shell + Utility image pull secrets                                                                                                                                                                                                                 | `[]`                       |
| `volumePermissions.resourcesPreset`                         | Set container resources according to one common preset (allowed values: none, nano, micro, small, medium, large, xlarge, 2xlarge). This is ignored if volumePermissions.resources is set (volumePermissions.resources is recommended for production). | `nano`                     |
| `volumePermissions.resources`                               | Set container requests and limits for different resources like CPU or memory (essential for production workloads)                                                                                                                                     | `{}`                       |
| `volumePermissions.containerSecurityContext.seLinuxOptions` | Set SELinux options in container                                                                                                                                                                                                                      | `{}`                       |
| `volumePermissions.containerSecurityContext.runAsUser`      | Set init container's Security Context runAsUser                                                                                                                                                                                                       | `0`                        |

### Other Parameters

| Name                                          | Description                                                            | Value   |
| --------------------------------------------- | ---------------------------------------------------------------------- | ------- |
| `serviceAccount.create`                       | Enable creation of ServiceAccount for Tempo pods                       | `true`  |
| `serviceAccount.name`                         | The name of the ServiceAccount to use                                  | `""`    |
| `serviceAccount.automountServiceAccountToken` | Allows auto mount of ServiceAccountToken on the serviceAccount created | `false` |
| `serviceAccount.annotations`                  | Additional custom annotations for the ServiceAccount                   | `{}`    |

### Metrics Parameters

| Name                                       | Description                                                                           | Value   |
| ------------------------------------------ | ------------------------------------------------------------------------------------- | ------- |
| `metrics.enabled`                          | Enable metrics                                                                        | `false` |
| `metrics.serviceMonitor.enabled`           | Create ServiceMonitor Resource for scraping metrics using Prometheus Operator         | `false` |
| `metrics.serviceMonitor.namespace`         | Namespace for the ServiceMonitor Resource (defaults to the Release Namespace)         | `""`    |
| `metrics.serviceMonitor.interval`          | Interval at which metrics should be scraped.                                          | `""`    |
| `metrics.serviceMonitor.scrapeTimeout`     | Timeout after which the scrape is ended                                               | `""`    |
| `metrics.serviceMonitor.labels`            | Additional labels that can be used so ServiceMonitor will be discovered by Prometheus | `{}`    |
| `metrics.serviceMonitor.selector`          | Prometheus instance selector labels                                                   | `{}`    |
| `metrics.serviceMonitor.relabelings`       | RelabelConfigs to apply to samples before scraping                                    | `[]`    |
| `metrics.serviceMonitor.metricRelabelings` | MetricRelabelConfigs to apply to samples before ingestion                             | `[]`    |
| `metrics.serviceMonitor.honorLabels`       | Specify honorLabels parameter to add the scrape endpoint                              | `false` |
| `metrics.serviceMonitor.jobLabel`          | The name of the label on the target service to use as the job name in prometheus.     | `""`    |

### External Memcached Parameters

| Name                     | Description                                   | Value   |
| ------------------------ | --------------------------------------------- | ------- |
| `externalMemcached.host` | Host of a running external memcached instance | `""`    |
| `externalMemcached.port` | Port of a running external memcached instance | `11211` |

### Memcached Sub-chart Parameters

| Name                                | Description                                                                                                                                                                                                | Value   |
| ----------------------------------- | ---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | ------- |
| `memcached.enabled`                 | Deploy memcached sub-chart                                                                                                                                                                                 | `true`  |
| `memcached.auth.enabled`            | Enable Memcached authentication                                                                                                                                                                            | `false` |
| `memcached.auth.username`           | Memcached admin user                                                                                                                                                                                       | `""`    |
| `memcached.auth.password`           | Memcached admin password                                                                                                                                                                                   | `""`    |
| `memcached.service.ports.memcached` | Memcached service port                                                                                                                                                                                     | `11211` |
| `memcached.resourcesPreset`         | Set container resources according to one common preset (allowed values: none, nano, small, medium, large, xlarge, 2xlarge). This is ignored if resources is set (resources is recommended for production). | `nano`  |
| `memcached.resources`               | Set container requests and limits for different resources like CPU or memory (essential for production workloads)                                                                                          | `{}`    |

Specify each parameter using the `--set key=value[,key=value]` argument to `helm install`. For example,

```console
helm install my-release \
  --set tempo.traces.jaeger.grpc=true \
  oci://REGISTRY_NAME/REPOSITORY_NAME/grafana-tempo
```

> Note: You need to substitute the placeholders `REGISTRY_NAME` and `REPOSITORY_NAME` with a reference to your Helm chart registry and repository. For example, in the case of Bitnami, you need to use `REGISTRY_NAME=registry-1.docker.io` and `REPOSITORY_NAME=bitnamicharts`.

The above command enables the Jaeger GRPC traces.

Alternatively, a YAML file that specifies the values for the above parameters can be provided while installing the chart. For example,

```console
helm install my-release -f values.yaml oci://REGISTRY_NAME/REPOSITORY_NAME/grafana-tempo
```

> Note: You need to substitute the placeholders `REGISTRY_NAME` and `REPOSITORY_NAME` with a reference to your Helm chart registry and repository. For example, in the case of Bitnami, you need to use `REGISTRY_NAME=registry-1.docker.io` and `REPOSITORY_NAME=bitnamicharts`.
> **Tip**: You can use the default [values.yaml](https://github.com/bitnami/charts/tree/main/bitnami/grafana-tempo/values.yaml)

## Troubleshooting

Find more information about how to deal with common errors related to Bitnami's Helm charts in [this troubleshooting guide](https://docs.bitnami.com/general/how-to/troubleshoot-helm-chart-issues).

## Upgrading

### To 3.0.0

This major bump changes the following security defaults:

- `runAsGroup` is changed from `0` to `1001`
- `readOnlyRootFilesystem` is set to `true`
- `resourcesPreset` is changed from `none` to the minimum size working in our test suites (NOTE: `resourcesPreset` is not meant for production usage, but `resources` adapted to your use case).
- `global.compatibility.openshift.adaptSecurityContext` is changed from `disabled` to `auto`.

This could potentially break any customization or init scripts used in your deployment. If this is the case, change the default values to the previous ones.

### To 2.0.0

This major release removes `search_enabled` and `metrics_generator_enabled` configuration parameters, assuming they are always enabled.

### To 1.0.0

This major release renames several values in this chart and adds missing features, in order to be inline with the rest of assets in the Bitnami charts repository.

- `tempo.containerPort`, `tempo.grpcContainerPort` and `tempo.gossipRing.containerPort` have been regrouped under the `tempo.containerPorts` map.
- `queryFrontend.query.jaegerMetricsContainerPort` and `queryFrontend.query.jaegerUIContainerPort` have been regrouped under the `queryFrontend.query.containerPorts` map.
- `vulture.containerPort` has been regrouped under the `vulture.containerPorts` map.
- `XXX.service.port` and `XXX.service.grpcPort` have been regrouped under the `XXX.service.ports` map.

Additionally updates the Memcached subchart to its newest major `6.x.x`, which contains similar changes.

## License

Copyright &copy; 2024 Broadcom. The term "Broadcom" refers to Broadcom Inc. and/or its subsidiaries.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

<http://www.apache.org/licenses/LICENSE-2.0>

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.